#include "swfdec_as_types.h"
#define SWFDEC_AS_NATIVE(x,y,func) void func (SwfdecAsContext *cx, \
    SwfdecAsObject *object, guint argc, SwfdecAsValue *argv, SwfdecAsValue *ret);
#define SWFDEC_AS_CONSTRUCTOR(x,y,func,type) SWFDEC_AS_NATIVE(x,y,func) GType type (void);
SWFDEC_AS_CONSTRUCTOR (252, 0, swfdec_as_array_construct, swfdec_as_array_get_type)
SWFDEC_AS_CONSTRUCTOR (107, 2, swfdec_as_boolean_construct, swfdec_as_boolean_get_type)
SWFDEC_AS_CONSTRUCTOR (103, 256, swfdec_as_date_construct, swfdec_as_date_get_type)
SWFDEC_AS_CONSTRUCTOR (106, 2, swfdec_as_number_construct, swfdec_as_number_get_type)
SWFDEC_AS_CONSTRUCTOR (251, 0, swfdec_as_string_construct, swfdec_as_string_get_type)
SWFDEC_AS_CONSTRUCTOR (1100, 0, swfdec_bitmap_data_construct, swfdec_bitmap_data_get_type)
SWFDEC_AS_CONSTRUCTOR (1105, 0, swfdec_color_transform_as_construct, swfdec_color_transform_as_get_type)
SWFDEC_AS_CONSTRUCTOR (112, 0, swfdec_movie_clip_loader_construct, swfdec_movie_clip_loader_get_type)
SWFDEC_AS_CONSTRUCTOR (2100, 200, swfdec_net_connection_construct, swfdec_net_connection_get_type)
SWFDEC_AS_CONSTRUCTOR (500, 16, swfdec_sound_object_construct, swfdec_sound_object_get_type)
SWFDEC_AS_CONSTRUCTOR (113, 0, swfdec_style_sheet_construct, swfdec_style_sheet_get_type)
SWFDEC_AS_CONSTRUCTOR (110, 0, swfdec_text_format_construct, swfdec_text_format_get_type)
SWFDEC_AS_CONSTRUCTOR (1106, 0, swfdec_transform_as_construct, swfdec_transform_as_get_type)
SWFDEC_AS_CONSTRUCTOR (253, 0, swfdec_xml_node_construct, swfdec_xml_node_get_type)
SWFDEC_AS_CONSTRUCTOR (253, 9, swfdec_xml_construct, swfdec_xml_get_type)
SWFDEC_AS_NATIVE (1999, 0, swfdec_accessibility_isActive)
SWFDEC_AS_NATIVE (1999, 1, swfdec_accessibility_sendEvent)
SWFDEC_AS_NATIVE (1999, 2, swfdec_accessibility_updateProperties)
SWFDEC_AS_NATIVE (252, 7, swfdec_as_array_join)
SWFDEC_AS_NATIVE (252, 9, swfdec_as_array_toString)
SWFDEC_AS_NATIVE (252, 1, swfdec_as_array_do_push)
SWFDEC_AS_NATIVE (252, 2, swfdec_as_array_do_pop)
SWFDEC_AS_NATIVE (252, 5, swfdec_as_array_do_unshift)
SWFDEC_AS_NATIVE (252, 4, swfdec_as_array_do_shift)
SWFDEC_AS_NATIVE (252, 11, swfdec_as_array_reverse)
SWFDEC_AS_NATIVE (252, 3, swfdec_as_array_concat)
SWFDEC_AS_NATIVE (252, 6, swfdec_as_array_slice)
SWFDEC_AS_NATIVE (252, 8, swfdec_as_array_splice)
SWFDEC_AS_NATIVE (252, 10, swfdec_as_array_sort)
SWFDEC_AS_NATIVE (252, 12, swfdec_as_array_sortOn)
SWFDEC_AS_NATIVE (107, 1, swfdec_as_boolean_toString)
SWFDEC_AS_NATIVE (107, 0, swfdec_as_boolean_valueOf)
SWFDEC_AS_NATIVE (3, 2, swfdec_as_boolean_old_constructor)
SWFDEC_AS_NATIVE (1, 0, swfdec_as_context_ASSetPropFlags)
SWFDEC_AS_NATIVE (200, 19, swfdec_as_context_isFinite)
SWFDEC_AS_NATIVE (200, 18, swfdec_as_context_isNaN)
SWFDEC_AS_NATIVE (100, 2, swfdec_as_context_parseInt)
SWFDEC_AS_NATIVE (100, 3, swfdec_as_context_parseFloat)
SWFDEC_AS_NATIVE (103, 19, swfdec_as_date_toString)
SWFDEC_AS_NATIVE (103, 16, swfdec_as_date_getTime)
SWFDEC_AS_NATIVE (103, 18, swfdec_as_date_getTimezoneOffset)
SWFDEC_AS_NATIVE (103, 8, swfdec_as_date_getMilliseconds)
SWFDEC_AS_NATIVE (103, 128 + 8, swfdec_as_date_getUTCMilliseconds)
SWFDEC_AS_NATIVE (103, 7, swfdec_as_date_getSeconds)
SWFDEC_AS_NATIVE (103, 128 + 7, swfdec_as_date_getUTCSeconds)
SWFDEC_AS_NATIVE (103, 6, swfdec_as_date_getMinutes)
SWFDEC_AS_NATIVE (103, 128 + 6, swfdec_as_date_getUTCMinutes)
SWFDEC_AS_NATIVE (103, 5, swfdec_as_date_getHours)
SWFDEC_AS_NATIVE (103, 128 + 5, swfdec_as_date_getUTCHours)
SWFDEC_AS_NATIVE (103, 4, swfdec_as_date_getDay)
SWFDEC_AS_NATIVE (103, 128 + 4, swfdec_as_date_getUTCDay)
SWFDEC_AS_NATIVE (103, 3, swfdec_as_date_getDate)
SWFDEC_AS_NATIVE (103, 128 + 3, swfdec_as_date_getUTCDate)
SWFDEC_AS_NATIVE (103, 2, swfdec_as_date_getMonth)
SWFDEC_AS_NATIVE (103, 128 + 2, swfdec_as_date_getUTCMonth)
SWFDEC_AS_NATIVE (103, 1, swfdec_as_date_getYear)
SWFDEC_AS_NATIVE (103, 128 + 1, swfdec_as_date_getUTCYear)
SWFDEC_AS_NATIVE (103, 0, swfdec_as_date_getFullYear)
SWFDEC_AS_NATIVE (103, 128 + 0, swfdec_as_date_getUTCFullYear)
SWFDEC_AS_NATIVE (103, 17, swfdec_as_date_setTime)
SWFDEC_AS_NATIVE (103, 15, swfdec_as_date_setMilliseconds)
SWFDEC_AS_NATIVE (103, 128 + 15, swfdec_as_date_setUTCMilliseconds)
SWFDEC_AS_NATIVE (103, 14, swfdec_as_date_setSeconds)
SWFDEC_AS_NATIVE (103, 128 + 14, swfdec_as_date_setUTCSeconds)
SWFDEC_AS_NATIVE (103, 13, swfdec_as_date_setMinutes)
SWFDEC_AS_NATIVE (103, 128 + 13, swfdec_as_date_setUTCMinutes)
SWFDEC_AS_NATIVE (103, 12, swfdec_as_date_setHours)
SWFDEC_AS_NATIVE (103, 128 + 12, swfdec_as_date_setUTCHours)
SWFDEC_AS_NATIVE (103, 11, swfdec_as_date_setDate)
SWFDEC_AS_NATIVE (103, 128 + 11, swfdec_as_date_setUTCDate)
SWFDEC_AS_NATIVE (103, 10, swfdec_as_date_setMonth)
SWFDEC_AS_NATIVE (103, 128 + 10, swfdec_as_date_setUTCMonth)
SWFDEC_AS_NATIVE (103, 20, swfdec_as_date_setYear)
SWFDEC_AS_NATIVE (103, 9, swfdec_as_date_setFullYear)
SWFDEC_AS_NATIVE (103, 128 + 9, swfdec_as_date_setUTCFullYear)
SWFDEC_AS_NATIVE (103, 257, swfdec_as_date_UTC)
SWFDEC_AS_NATIVE (101, 10, swfdec_as_function_do_call)
SWFDEC_AS_NATIVE (101, 11, swfdec_as_function_apply)
SWFDEC_AS_NATIVE (200, 16, swfdec_as_math_acos)
SWFDEC_AS_NATIVE (200, 15, swfdec_as_math_asin)
SWFDEC_AS_NATIVE (200, 14, swfdec_as_math_atan)
SWFDEC_AS_NATIVE (200, 13, swfdec_as_math_ceil)
SWFDEC_AS_NATIVE (200, 4, swfdec_as_math_cos)
SWFDEC_AS_NATIVE (200, 7, swfdec_as_math_exp)
SWFDEC_AS_NATIVE (200, 12, swfdec_as_math_floor)
SWFDEC_AS_NATIVE (200, 8, swfdec_as_math_log)
SWFDEC_AS_NATIVE (200, 3, swfdec_as_math_sin)
SWFDEC_AS_NATIVE (200, 9, swfdec_as_math_sqrt)
SWFDEC_AS_NATIVE (200, 6, swfdec_as_math_tan)
SWFDEC_AS_NATIVE (200, 0, swfdec_as_math_abs)
SWFDEC_AS_NATIVE (200, 5, swfdec_as_math_atan2)
SWFDEC_AS_NATIVE (200, 2, swfdec_as_math_max)
SWFDEC_AS_NATIVE (200, 1, swfdec_as_math_min)
SWFDEC_AS_NATIVE (200, 17, swfdec_as_math_pow)
SWFDEC_AS_NATIVE (200, 11, swfdec_as_math_random)
SWFDEC_AS_NATIVE (200, 10, swfdec_as_math_round)
SWFDEC_AS_NATIVE (106, 1, swfdec_as_number_toString)
SWFDEC_AS_NATIVE (106, 0, swfdec_as_number_valueOf)
SWFDEC_AS_NATIVE (3, 1, swfdec_as_number_old_constructor)
SWFDEC_AS_NATIVE (3, 4, swfdec_as_number_old_toString)
SWFDEC_AS_NATIVE (101, 2, swfdec_as_object_addProperty)
SWFDEC_AS_NATIVE (101, 5, swfdec_as_object_hasOwnProperty)
SWFDEC_AS_NATIVE (101, 7, swfdec_as_object_isPropertyEnumerable)
SWFDEC_AS_NATIVE (101, 6, swfdec_as_object_isPrototypeOf)
SWFDEC_AS_NATIVE (101, 0, swfdec_as_object_watch)
SWFDEC_AS_NATIVE (101, 1, swfdec_as_object_unwatch)
SWFDEC_AS_NATIVE (101, 3, swfdec_as_object_valueOf)
SWFDEC_AS_NATIVE (101, 4, swfdec_as_object_toString)
SWFDEC_AS_NATIVE (3, 3, swfdec_as_object_old_constructor)
SWFDEC_AS_NATIVE (251, 9, swfdec_as_string_lastIndexOf)
SWFDEC_AS_NATIVE (251, 8, swfdec_as_string_indexOf)
SWFDEC_AS_NATIVE (251, 5, swfdec_as_string_charAt)
SWFDEC_AS_NATIVE (251, 6, swfdec_as_string_charCodeAt)
SWFDEC_AS_NATIVE (251, 14, swfdec_as_string_fromCharCode)
SWFDEC_AS_NATIVE (251, 2, swfdec_as_string_toString)
SWFDEC_AS_NATIVE (251, 1, swfdec_as_string_valueOf)
SWFDEC_AS_NATIVE (251, 12, swfdec_as_string_split)
SWFDEC_AS_NATIVE (251, 10, swfdec_as_string_slice)
SWFDEC_AS_NATIVE (251, 7, swfdec_as_string_concat)
SWFDEC_AS_NATIVE (251, 13, swfdec_as_string_substr)
SWFDEC_AS_NATIVE (251, 11, swfdec_as_string_substring)
SWFDEC_AS_NATIVE (251, 4, swfdec_as_string_toLowerCase)
SWFDEC_AS_NATIVE (251, 3, swfdec_as_string_toUpperCase)
SWFDEC_AS_NATIVE (102, 1, swfdec_as_string_old_toLowerCase)
SWFDEC_AS_NATIVE (102, 0, swfdec_as_string_old_toUpperCase)
SWFDEC_AS_NATIVE (100, 0, swfdec_as_string_escape_internal)
SWFDEC_AS_NATIVE (100, 1, swfdec_as_string_unescape_internal)
SWFDEC_AS_NATIVE (3, 0, swfdec_as_string_old_constructor)
SWFDEC_AS_NATIVE (101, 12, broadcastMessage)
SWFDEC_AS_NATIVE (1107, 1, swfdec_bevel_filter_get_distance)
SWFDEC_AS_NATIVE (1107, 2, swfdec_bevel_filter_set_distance)
SWFDEC_AS_NATIVE (1107, 3, swfdec_bevel_filter_get_angle)
SWFDEC_AS_NATIVE (1107, 4, swfdec_bevel_filter_set_angle)
SWFDEC_AS_NATIVE (1107, 5, swfdec_bevel_filter_get_highlightColor)
SWFDEC_AS_NATIVE (1107, 6, swfdec_bevel_filter_set_highlightColor)
SWFDEC_AS_NATIVE (1107, 7, swfdec_bevel_filter_get_highlightAlpha)
SWFDEC_AS_NATIVE (1107, 8, swfdec_bevel_filter_set_highlightAlpha)
SWFDEC_AS_NATIVE (1107, 9, swfdec_bevel_filter_get_shadowColor)
SWFDEC_AS_NATIVE (1107, 10, swfdec_bevel_filter_set_shadowColor)
SWFDEC_AS_NATIVE (1107, 11, swfdec_bevel_filter_get_shadowAlpha)
SWFDEC_AS_NATIVE (1107, 12, swfdec_bevel_filter_set_shadowAlpha)
SWFDEC_AS_NATIVE (1107, 13, swfdec_bevel_filter_get_quality)
SWFDEC_AS_NATIVE (1107, 14, swfdec_bevel_filter_set_quality)
SWFDEC_AS_NATIVE (1107, 15, swfdec_bevel_filter_get_strength)
SWFDEC_AS_NATIVE (1107, 16, swfdec_bevel_filter_set_strength)
SWFDEC_AS_NATIVE (1107, 17, swfdec_bevel_filter_get_knockout)
SWFDEC_AS_NATIVE (1107, 18, swfdec_bevel_filter_set_knockout)
SWFDEC_AS_NATIVE (1107, 19, swfdec_bevel_filter_get_blurX)
SWFDEC_AS_NATIVE (1107, 20, swfdec_bevel_filter_set_blurX)
SWFDEC_AS_NATIVE (1107, 21, swfdec_bevel_filter_get_blurY)
SWFDEC_AS_NATIVE (1107, 22, swfdec_bevel_filter_set_blurY)
SWFDEC_AS_NATIVE (1107, 23, swfdec_bevel_filter_get_type)
SWFDEC_AS_NATIVE (1107, 24, swfdec_bevel_filter_set_type)
SWFDEC_AS_NATIVE (1107, 0, swfdec_bevel_filter_construct)
SWFDEC_AS_NATIVE (1100, 40, swfdec_bitmap_data_loadBitmap)
SWFDEC_AS_NATIVE (1100, 100, swfdec_bitmap_data_get_width)
SWFDEC_AS_NATIVE (1100, 101, swfdec_bitmap_data_set_width)
SWFDEC_AS_NATIVE (1100, 102, swfdec_bitmap_data_get_height)
SWFDEC_AS_NATIVE (1100, 103, swfdec_bitmap_data_set_height)
SWFDEC_AS_NATIVE (1100, 104, swfdec_bitmap_data_get_rectangle)
SWFDEC_AS_NATIVE (1100, 105, swfdec_bitmap_data_set_rectangle)
SWFDEC_AS_NATIVE (1100, 106, swfdec_bitmap_data_get_transparent)
SWFDEC_AS_NATIVE (1100, 107, swfdec_bitmap_data_set_transparent)
SWFDEC_AS_NATIVE (1100, 1, swfdec_bitmap_data_getPixel)
SWFDEC_AS_NATIVE (1100, 2, swfdec_bitmap_data_setPixel)
SWFDEC_AS_NATIVE (1100, 3, swfdec_bitmap_data_fillRect)
SWFDEC_AS_NATIVE (1100, 4, swfdec_bitmap_data_copyPixels)
SWFDEC_AS_NATIVE (1100, 5, swfdec_bitmap_data_applyFilter)
SWFDEC_AS_NATIVE (1100, 6, swfdec_bitmap_data_scroll)
SWFDEC_AS_NATIVE (1100, 7, swfdec_bitmap_data_threshold)
SWFDEC_AS_NATIVE (1100, 8, swfdec_bitmap_data_draw)
SWFDEC_AS_NATIVE (1100, 9, swfdec_bitmap_data_pixelDissolve)
SWFDEC_AS_NATIVE (1100, 10, swfdec_bitmap_data_getPixel32)
SWFDEC_AS_NATIVE (1100, 11, swfdec_bitmap_data_setPixel32)
SWFDEC_AS_NATIVE (1100, 12, swfdec_bitmap_data_floodFill)
SWFDEC_AS_NATIVE (1100, 13, swfdec_bitmap_data_getColorBoundsRect)
SWFDEC_AS_NATIVE (1100, 14, swfdec_bitmap_data_perlinNoise)
SWFDEC_AS_NATIVE (1100, 15, swfdec_bitmap_data_colorTransform)
SWFDEC_AS_NATIVE (1100, 16, swfdec_bitmap_data_hitTest)
SWFDEC_AS_NATIVE (1100, 17, swfdec_bitmap_data_paletteMap)
SWFDEC_AS_NATIVE (1100, 18, swfdec_bitmap_data_merge)
SWFDEC_AS_NATIVE (1100, 19, swfdec_bitmap_data_noise)
SWFDEC_AS_NATIVE (1100, 20, swfdec_bitmap_data_copyChannel)
SWFDEC_AS_NATIVE (1100, 21, swfdec_bitmap_data_clone)
SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_do_dispose)
SWFDEC_AS_NATIVE (1100, 23, swfdec_bitmap_data_generateFilterRect)
SWFDEC_AS_NATIVE (1100, 24, swfdec_bitmap_data_compare)
SWFDEC_AS_NATIVE (1112, 1, swfdec_bitmap_filter_getPixel)
SWFDEC_AS_NATIVE (1112, 0, swfdec_bitmap_filter_construct)
SWFDEC_AS_NATIVE (1102, 1, swfdec_blur_filter_get_blurX)
SWFDEC_AS_NATIVE (1102, 2, swfdec_blur_filter_set_blurX)
SWFDEC_AS_NATIVE (1102, 3, swfdec_blur_filter_get_blurY)
SWFDEC_AS_NATIVE (1102, 4, swfdec_blur_filter_set_blurY)
SWFDEC_AS_NATIVE (1102, 5, swfdec_blur_filter_get_quality)
SWFDEC_AS_NATIVE (1102, 6, swfdec_blur_filter_set_quality)
SWFDEC_AS_NATIVE (1102, 0, swfdec_blur_filter_construct)
SWFDEC_AS_NATIVE (105, 4, swfdec_button_get_scale9Grid)
SWFDEC_AS_NATIVE (105, 5, swfdec_button_set_scale9Grid)
SWFDEC_AS_NATIVE (105, 6, swfdec_button_get_filters)
SWFDEC_AS_NATIVE (105, 7, swfdec_button_set_filters)
SWFDEC_AS_NATIVE (105, 8, swfdec_button_get_cacheAsBitmap)
SWFDEC_AS_NATIVE (105, 9, swfdec_button_set_cacheAsBitmap)
SWFDEC_AS_NATIVE (105, 10, swfdec_button_get_blendMode)
SWFDEC_AS_NATIVE (105, 11, swfdec_button_set_blendMode)
SWFDEC_AS_NATIVE (105, 3, swfdec_button_movie_getDepth)
SWFDEC_AS_NATIVE (105, 0, swfdec_button_movie_construct)
SWFDEC_AS_NATIVE (2102, 200, swfdec_camera_get)
SWFDEC_AS_NATIVE (2102, 201, swfdec_camera_names_get)
SWFDEC_AS_NATIVE (2102, 0, swfdec_camera_setMode)
SWFDEC_AS_NATIVE (2102, 1, swfdec_camera_setQuality)
SWFDEC_AS_NATIVE (2102, 2, swfdec_camera_setKeyFrameInterval)
SWFDEC_AS_NATIVE (2102, 3, swfdec_camera_setMotionLevel)
SWFDEC_AS_NATIVE (2102, 4, swfdec_camera_setLoopback)
SWFDEC_AS_NATIVE (2102, 5, swfdec_camera_setCursor)
SWFDEC_AS_NATIVE (700, 2, swfdec_movie_color_getRGB)
SWFDEC_AS_NATIVE (700, 3, swfdec_movie_color_getTransform)
SWFDEC_AS_NATIVE (700, 0, swfdec_movie_color_setRGB)
SWFDEC_AS_NATIVE (700, 1, swfdec_movie_color_setTransform)
SWFDEC_AS_NATIVE (1110, 1, swfdec_color_matrix_filter_get_matrix)
SWFDEC_AS_NATIVE (1110, 2, swfdec_color_matrix_filter_set_matrix)
SWFDEC_AS_NATIVE (1110, 0, swfdec_color_matrix_filter_contruct)
SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_as_get_alphaMultiplier)
SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_as_set_alphaMultiplier)
SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_as_get_redMultiplier)
SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_as_set_redMultiplier)
SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_as_get_greenMultiplier)
SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_as_set_greenMultiplier)
SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_as_get_blueMultiplier)
SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_as_set_blueMultiplier)
SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_as_get_alphaOffset)
SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_as_set_alphaOffset)
SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_as_get_redOffset)
SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_as_set_redOffset)
SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_as_get_greenOffset)
SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_as_set_greenOffset)
SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_as_get_blueOffset)
SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_as_set_blueOffset)
SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_as_get_rgb)
SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_as_set_rgb)
SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_as_concat)
SWFDEC_AS_NATIVE (1109, 1, swfdec_convolution_filter_get_matrixX)
SWFDEC_AS_NATIVE (1109, 2, swfdec_convolution_filter_set_matrixX)
SWFDEC_AS_NATIVE (1109, 3, swfdec_convolution_filter_get_matrixY)
SWFDEC_AS_NATIVE (1109, 4, swfdec_convolution_filter_set_matrixY)
SWFDEC_AS_NATIVE (1109, 5, swfdec_convolution_filter_get_matrix)
SWFDEC_AS_NATIVE (1109, 6, swfdec_convolution_filter_set_matrix)
SWFDEC_AS_NATIVE (1109, 7, swfdec_convolution_filter_get_divisor)
SWFDEC_AS_NATIVE (1109, 8, swfdec_convolution_filter_set_divisor)
SWFDEC_AS_NATIVE (1109, 9, swfdec_convolution_filter_get_bias)
SWFDEC_AS_NATIVE (1109, 10, swfdec_convolution_filter_set_bias)
SWFDEC_AS_NATIVE (1109, 11, swfdec_convolution_filter_get_preserveAlpha)
SWFDEC_AS_NATIVE (1109, 12, swfdec_convolution_filter_set_preserveAlpha)
SWFDEC_AS_NATIVE (1109, 13, swfdec_convolution_filter_get_clamp)
SWFDEC_AS_NATIVE (1109, 14, swfdec_convolution_filter_set_clamp)
SWFDEC_AS_NATIVE (1109, 15, swfdec_convolution_filter_get_color)
SWFDEC_AS_NATIVE (1109, 16, swfdec_convolution_filter_set_color)
SWFDEC_AS_NATIVE (1109, 17, swfdec_convolution_filter_get_alpha)
SWFDEC_AS_NATIVE (1109, 18, swfdec_convolution_filter_set_alpha)
SWFDEC_AS_NATIVE (1109, 0, swfdec_convolution_filter_contruct)
SWFDEC_AS_NATIVE (1111, 1, swfdec_displacement_map_filter_get_mapBitmap)
SWFDEC_AS_NATIVE (1111, 2, swfdec_displacement_map_filter_set_mapBitmap)
SWFDEC_AS_NATIVE (1111, 3, swfdec_displacement_map_filter_get_mapPoint)
SWFDEC_AS_NATIVE (1111, 4, swfdec_displacement_map_filter_set_mapPoint)
SWFDEC_AS_NATIVE (1111, 5, swfdec_displacement_map_filter_get_componentX)
SWFDEC_AS_NATIVE (1111, 6, swfdec_displacement_map_filter_set_componentX)
SWFDEC_AS_NATIVE (1111, 7, swfdec_displacement_map_filter_get_componentY)
SWFDEC_AS_NATIVE (1111, 8, swfdec_displacement_map_filter_set_componentY)
SWFDEC_AS_NATIVE (1111, 9, swfdec_displacement_map_filter_get_scaleX)
SWFDEC_AS_NATIVE (1111, 10, swfdec_displacement_map_filter_set_scaleX)
SWFDEC_AS_NATIVE (1111, 11, swfdec_displacement_map_filter_get_scaleY)
SWFDEC_AS_NATIVE (1111, 12, swfdec_displacement_map_filter_set_scaleY)
SWFDEC_AS_NATIVE (1111, 13, swfdec_displacement_map_filter_get_mode)
SWFDEC_AS_NATIVE (1111, 14, swfdec_displacement_map_filter_set_mode)
SWFDEC_AS_NATIVE (1111, 15, swfdec_displacement_map_filter_get_color)
SWFDEC_AS_NATIVE (1111, 16, swfdec_displacement_map_filter_set_color)
SWFDEC_AS_NATIVE (1111, 17, swfdec_displacement_map_filter_get_alpha)
SWFDEC_AS_NATIVE (1111, 18, swfdec_displacement_map_filter_set_alpha)
SWFDEC_AS_NATIVE (1111, 0, swfdec_displacement_map_filter_contruct)
SWFDEC_AS_NATIVE (1101, 1, swfdec_drop_shadow_filter_get_distance)
SWFDEC_AS_NATIVE (1101, 2, swfdec_drop_shadow_filter_set_distance)
SWFDEC_AS_NATIVE (1101, 3, swfdec_drop_shadow_filter_get_angle)
SWFDEC_AS_NATIVE (1101, 4, swfdec_drop_shadow_filter_set_angle)
SWFDEC_AS_NATIVE (1101, 5, swfdec_drop_shadow_filter_get_color)
SWFDEC_AS_NATIVE (1101, 6, swfdec_drop_shadow_filter_set_color)
SWFDEC_AS_NATIVE (1101, 7, swfdec_drop_shadow_filter_get_alpha)
SWFDEC_AS_NATIVE (1101, 8, swfdec_drop_shadow_filter_set_alpha)
SWFDEC_AS_NATIVE (1101, 9, swfdec_drop_shadow_filter_get_quality)
SWFDEC_AS_NATIVE (1101, 10, swfdec_drop_shadow_filter_set_quality)
SWFDEC_AS_NATIVE (1101, 11, swfdec_drop_shadow_filter_get_inner)
SWFDEC_AS_NATIVE (1101, 12, swfdec_drop_shadow_filter_set_inner)
SWFDEC_AS_NATIVE (1101, 13, swfdec_drop_shadow_filter_get_knockout)
SWFDEC_AS_NATIVE (1101, 14, swfdec_drop_shadow_filter_set_knockout)
SWFDEC_AS_NATIVE (1101, 15, swfdec_drop_shadow_filter_get_blurX)
SWFDEC_AS_NATIVE (1101, 16, swfdec_drop_shadow_filter_set_blurX)
SWFDEC_AS_NATIVE (1101, 17, swfdec_drop_shadow_filter_get_blurY)
SWFDEC_AS_NATIVE (1101, 18, swfdec_drop_shadow_filter_set_blurY)
SWFDEC_AS_NATIVE (1101, 19, swfdec_drop_shadow_filter_get_strength)
SWFDEC_AS_NATIVE (1101, 20, swfdec_drop_shadow_filter_set_strength)
SWFDEC_AS_NATIVE (1101, 21, swfdec_drop_shadow_filter_get_hideObject)
SWFDEC_AS_NATIVE (1101, 22, swfdec_drop_shadow_filter_set_hideObject)
SWFDEC_AS_NATIVE (1101, 0, swfdec_drop_shadow_filter_construct)
SWFDEC_AS_NATIVE (14, 0, swfdec_external_interface__initJS)
SWFDEC_AS_NATIVE (14, 1, swfdec_external_interface__objectID)
SWFDEC_AS_NATIVE (14, 2, swfdec_external_interface__addCallback)
SWFDEC_AS_NATIVE (14, 3, swfdec_external_interface__evalJS)
SWFDEC_AS_NATIVE (14, 4, swfdec_external_interface__callOut)
SWFDEC_AS_NATIVE (14, 5, swfdec_external_interface__escapeXML)
SWFDEC_AS_NATIVE (14, 6, swfdec_external_interface__unescapeXML)
SWFDEC_AS_NATIVE (14, 7, swfdec_external_interface__jsQuoteString)
SWFDEC_AS_NATIVE (14, 100, swfdec_external_interface_get_available)
SWFDEC_AS_NATIVE (14, 101, swfdec_external_interface_set_available)
SWFDEC_AS_NATIVE (2204, 0, swfdec_file_reference_browse)
SWFDEC_AS_NATIVE (2204, 1, swfdec_file_reference_upload)
SWFDEC_AS_NATIVE (2204, 2, swfdec_file_reference_download)
SWFDEC_AS_NATIVE (2204, 3, swfdec_file_reference_cancel)
SWFDEC_AS_NATIVE (2204, 200, swfdec_file_reference_construct)
SWFDEC_AS_NATIVE (2205, 0, swfdec_file_reference_list_browse)
SWFDEC_AS_NATIVE (1112, 1, swfdec_filter_clone)
SWFDEC_AS_NATIVE (1103, 1, swfdec_glow_filter_get_distance)
SWFDEC_AS_NATIVE (1103, 2, swfdec_glow_filter_set_distance)
SWFDEC_AS_NATIVE (1103, 3, swfdec_glow_filter_get_alpha)
SWFDEC_AS_NATIVE (1103, 4, swfdec_glow_filter_set_alpha)
SWFDEC_AS_NATIVE (1103, 5, swfdec_glow_filter_get_quality)
SWFDEC_AS_NATIVE (1103, 6, swfdec_glow_filter_set_quality)
SWFDEC_AS_NATIVE (1103, 7, swfdec_glow_filter_get_inner)
SWFDEC_AS_NATIVE (1103, 8, swfdec_glow_filter_set_inner)
SWFDEC_AS_NATIVE (1103, 9, swfdec_glow_filter_get_knockout)
SWFDEC_AS_NATIVE (1103, 10, swfdec_glow_filter_set_knockout)
SWFDEC_AS_NATIVE (1103, 11, swfdec_glow_filter_get_blurX)
SWFDEC_AS_NATIVE (1103, 12, swfdec_glow_filter_set_blurX)
SWFDEC_AS_NATIVE (1103, 13, swfdec_glow_filter_get_blurY)
SWFDEC_AS_NATIVE (1103, 14, swfdec_glow_filter_set_blurY)
SWFDEC_AS_NATIVE (1103, 15, swfdec_glow_filter_get_strength)
SWFDEC_AS_NATIVE (1103, 16, swfdec_glow_filter_set_strength)
SWFDEC_AS_NATIVE (1103, 0, swfdec_glow_filter_construct)
SWFDEC_AS_NATIVE (1108, 1, swfdec_gradient_filter_get_distance)
SWFDEC_AS_NATIVE (1108, 2, swfdec_gradient_filter_set_distance)
SWFDEC_AS_NATIVE (1108, 3, swfdec_gradient_filter_get_angle)
SWFDEC_AS_NATIVE (1108, 4, swfdec_gradient_filter_set_angle)
SWFDEC_AS_NATIVE (1108, 5, swfdec_gradient_filter_get_colors)
SWFDEC_AS_NATIVE (1108, 6, swfdec_gradient_filter_set_colors)
SWFDEC_AS_NATIVE (1108, 7, swfdec_gradient_filter_get_alphas)
SWFDEC_AS_NATIVE (1108, 8, swfdec_gradient_filter_set_alphas)
SWFDEC_AS_NATIVE (1108, 9, swfdec_gradient_filter_get_ratios)
SWFDEC_AS_NATIVE (1108, 10, swfdec_gradient_filter_set_ratios)
SWFDEC_AS_NATIVE (1108, 11, swfdec_gradient_filter_get_blurX)
SWFDEC_AS_NATIVE (1108, 12, swfdec_gradient_filter_set_blurX)
SWFDEC_AS_NATIVE (1108, 13, swfdec_gradient_filter_get_blurY)
SWFDEC_AS_NATIVE (1108, 14, swfdec_gradient_filter_set_blurY)
SWFDEC_AS_NATIVE (1108, 15, swfdec_gradient_filter_get_quality)
SWFDEC_AS_NATIVE (1108, 16, swfdec_gradient_filter_set_quality)
SWFDEC_AS_NATIVE (1108, 17, swfdec_gradient_filter_get_strength)
SWFDEC_AS_NATIVE (1108, 18, swfdec_gradient_filter_set_strength)
SWFDEC_AS_NATIVE (1108, 19, swfdec_gradient_filter_get_knockout)
SWFDEC_AS_NATIVE (1108, 20, swfdec_gradient_filter_set_knockout)
SWFDEC_AS_NATIVE (1108, 21, swfdec_gradient_filter_get_type)
SWFDEC_AS_NATIVE (1108, 22, swfdec_gradient_filter_set_type)
SWFDEC_AS_NATIVE (1108, 0, swfdec_gradient_glow_filter_construct)
SWFDEC_AS_NATIVE (1108, 1000, swfdec_gradient_bevel_filter_construct)
SWFDEC_AS_NATIVE (800, 0, swfdec_key_getAscii)
SWFDEC_AS_NATIVE (800, 1, swfdec_key_getCode)
SWFDEC_AS_NATIVE (800, 2, swfdec_key_isDown)
SWFDEC_AS_NATIVE (800, 3, swfdec_key_isToggled)
SWFDEC_AS_NATIVE (800, 4, swfdec_key_isAccessible)
SWFDEC_AS_NATIVE (301, 0, swfdec_load_object_as_load)
SWFDEC_AS_NATIVE (301, 1, swfdec_load_object_as_send)
SWFDEC_AS_NATIVE (301, 2, swfdec_load_object_as_sendAndLoad)
SWFDEC_AS_NATIVE (301, 3, swfdec_loadvars_decode)
SWFDEC_AS_NATIVE (2200, 0, swfdec_local_connection_connect)
SWFDEC_AS_NATIVE (2200, 1, swfdec_local_connection_send)
SWFDEC_AS_NATIVE (2200, 2, swfdec_local_connection_close)
SWFDEC_AS_NATIVE (2200, 3, swfdec_local_connection_domain)
SWFDEC_AS_NATIVE (2104, 200, swfdec_microphone_get)
SWFDEC_AS_NATIVE (2104, 201, swfdec_microphone_names_get)
SWFDEC_AS_NATIVE (2104, 0, swfdec_microphone_setSilenceLevel)
SWFDEC_AS_NATIVE (2104, 1, swfdec_microphone_setRate)
SWFDEC_AS_NATIVE (2104, 2, swfdec_microphone_setGain)
SWFDEC_AS_NATIVE (2104, 3, swfdec_microphone_setUseEchoSuppression)
SWFDEC_AS_NATIVE (5, 0, swfdec_mouse_show)
SWFDEC_AS_NATIVE (5, 1, swfdec_mouse_hide)
SWFDEC_AS_NATIVE (901, 1, swfdec_sprite_movie_beginFill)
SWFDEC_AS_NATIVE (901, 2, swfdec_sprite_movie_beginGradientFill)
SWFDEC_AS_NATIVE (901, 3, swfdec_sprite_movie_moveTo)
SWFDEC_AS_NATIVE (901, 4, swfdec_sprite_movie_lineTo)
SWFDEC_AS_NATIVE (901, 5, swfdec_sprite_movie_curveTo)
SWFDEC_AS_NATIVE (901, 6, swfdec_sprite_movie_lineStyle)
SWFDEC_AS_NATIVE (901, 7, swfdec_sprite_movie_endFill)
SWFDEC_AS_NATIVE (901, 8, swfdec_sprite_movie_clear)
SWFDEC_AS_NATIVE (901, 9, swfdec_sprite_movie_lineGradientStyle)
SWFDEC_AS_NATIVE (901, 10, swfdec_sprite_movie_beginMeshFill)
SWFDEC_AS_NATIVE (901, 11, swfdec_sprite_movie_beginBitmapFill)
SWFDEC_AS_NATIVE (901, 12, swfdec_sprite_movie_get_scale9Grid)
SWFDEC_AS_NATIVE (901, 13, swfdec_sprite_movie_set_scale9Grid)
SWFDEC_AS_NATIVE (112, 100, swfdec_movie_clip_loader_loadClip)
SWFDEC_AS_NATIVE (112, 102, swfdec_movie_clip_loader_unloadClip)
SWFDEC_AS_NATIVE (112, 101, swfdec_movie_clip_loader_getProgress)
SWFDEC_AS_NATIVE (2100, 0, swfdec_net_connection_do_connect)
SWFDEC_AS_NATIVE (2100, 1, swfdec_net_connection_do_close)
SWFDEC_AS_NATIVE (2100, 2, swfdec_net_connection_do_call)
SWFDEC_AS_NATIVE (2100, 3, swfdec_net_connection_do_addHeader)
SWFDEC_AS_NATIVE (2100, 4, swfdec_net_connection_get_connectedProxyType)
SWFDEC_AS_NATIVE (2100, 5, swfdec_net_connection_get_usingTLS)
SWFDEC_AS_NATIVE (2101, 0, swfdec_net_stream_close)
SWFDEC_AS_NATIVE (2101, 1, swfdec_net_stream_attachAudio)
SWFDEC_AS_NATIVE (2101, 2, swfdec_net_stream_attachVideo)
SWFDEC_AS_NATIVE (2101, 3, swfdec_net_stream_send)
SWFDEC_AS_NATIVE (2101, 4, swfdec_net_stream_setBufferTime)
SWFDEC_AS_NATIVE (2101, 5, swfdec_net_stream_get_checkPolicyFile)
SWFDEC_AS_NATIVE (2101, 6, swfdec_net_stream_set_checkPolicyFile)
SWFDEC_AS_NATIVE (2, 0, swfdec_player_ASnew)
SWFDEC_AS_NATIVE (250, 0, swfdec_player_setInterval)
SWFDEC_AS_NATIVE (250, 2, swfdec_player_setTimeout)
SWFDEC_AS_NATIVE (250, 1, swfdec_player_clearInterval)
SWFDEC_AS_NATIVE (100, 4, swfdec_player_trace)
SWFDEC_AS_NATIVE (9, 0, swfdec_player_updateAfterEvent)
SWFDEC_AS_NATIVE (1021, 1, swfdec_player_showRedrawRegions)
SWFDEC_AS_NATIVE (4, 0, ASSetNative)
SWFDEC_AS_NATIVE (4, 1, ASSetNativeAccessor)
SWFDEC_AS_NATIVE (101, 8, swfdec_player_object_registerClass)
SWFDEC_AS_NATIVE (111, 100, swfdec_print_job_start)
SWFDEC_AS_NATIVE (111, 101, swfdec_print_job_addPage)
SWFDEC_AS_NATIVE (111, 102, swfdec_print_job_send)
SWFDEC_AS_NATIVE (111, 0, swfdec_print_job_construct)
SWFDEC_AS_NATIVE (600, 0, swfdec_selection_getBeginIndex)
SWFDEC_AS_NATIVE (600, 1, swfdec_selection_getEndIndex)
SWFDEC_AS_NATIVE (600, 2, swfdec_selection_getCaretIndex)
SWFDEC_AS_NATIVE (600, 3, swfdec_selection_getFocus)
SWFDEC_AS_NATIVE (600, 4, swfdec_selection_setFocus)
SWFDEC_AS_NATIVE (600, 5, swfdec_selection_setSelection)
SWFDEC_AS_NATIVE (2106, 0, swfdec_shared_object_connect)
SWFDEC_AS_NATIVE (2106, 1, swfdec_shared_object_send)
SWFDEC_AS_NATIVE (2106, 2, swfdec_shared_object_flush)
SWFDEC_AS_NATIVE (2106, 3, swfdec_shared_object_close)
SWFDEC_AS_NATIVE (2106, 4, swfdec_shared_object_getSize)
SWFDEC_AS_NATIVE (2106, 5, swfdec_shared_object_setFps)
SWFDEC_AS_NATIVE (2106, 6, swfdec_shared_object_clear)
SWFDEC_AS_NATIVE (500, 0, swfdec_sound_object_getPan)
SWFDEC_AS_NATIVE (500, 1, swfdec_sound_object_getTransform)
SWFDEC_AS_NATIVE (500, 2, swfdec_sound_object_getVolume)
SWFDEC_AS_NATIVE (500, 3, swfdec_sound_object_setPan)
SWFDEC_AS_NATIVE (500, 4, swfdec_sound_object_setTransform)
SWFDEC_AS_NATIVE (500, 5, swfdec_sound_object_setVolume)
SWFDEC_AS_NATIVE (500, 9, swfdec_sound_object_getDuration)
SWFDEC_AS_NATIVE (500, 10, swfdec_sound_object_setDuration)
SWFDEC_AS_NATIVE (500, 11, swfdec_sound_object_getPosition)
SWFDEC_AS_NATIVE (500, 12, swfdec_sound_object_setPosition)
SWFDEC_AS_NATIVE (500, 13, swfdec_sound_object_loadSound)
SWFDEC_AS_NATIVE (500, 14, swfdec_sound_object_getBytesLoaded)
SWFDEC_AS_NATIVE (500, 15, swfdec_sound_object_getBytesTotal)
SWFDEC_AS_NATIVE (500, 18, swfdec_sound_object_get_checkPolicyFile)
SWFDEC_AS_NATIVE (500, 19, swfdec_sound_object_set_checkPolicyFile)
SWFDEC_AS_NATIVE (500, 16, swfdec_sound_object_areSoundsInaccessible)
SWFDEC_AS_NATIVE (500, 7, swfdec_sound_object_attachSound)
SWFDEC_AS_NATIVE (500, 8, swfdec_sound_object_start)
SWFDEC_AS_NATIVE (500, 6, swfdec_sound_object_stop)
SWFDEC_AS_NATIVE (900, 200, swfdec_sprite_movie_get_tabIndex)
SWFDEC_AS_NATIVE (900, 201, swfdec_sprite_movie_set_tabIndex)
SWFDEC_AS_NATIVE (900, 300, swfdec_sprite_movie_get__lockroot)
SWFDEC_AS_NATIVE (900, 301, swfdec_sprite_movie_set__lockroot)
SWFDEC_AS_NATIVE (900, 401, swfdec_sprite_movie_get_cacheAsBitmap)
SWFDEC_AS_NATIVE (900, 402, swfdec_sprite_movie_set_cacheAsBitmap)
SWFDEC_AS_NATIVE (900, 403, swfdec_sprite_movie_get_opaqueBackground)
SWFDEC_AS_NATIVE (900, 404, swfdec_sprite_movie_set_opaqueBackground)
SWFDEC_AS_NATIVE (900, 405, swfdec_sprite_movie_get_scrollRect)
SWFDEC_AS_NATIVE (900, 406, swfdec_sprite_movie_set_scrollRect)
SWFDEC_AS_NATIVE (900, 417, swfdec_sprite_movie_get_filters)
SWFDEC_AS_NATIVE (900, 418, swfdec_sprite_movie_set_filters)
SWFDEC_AS_NATIVE (900, 419, swfdec_sprite_movie_get_transform)
SWFDEC_AS_NATIVE (900, 420, swfdec_sprite_movie_set_transform)
SWFDEC_AS_NATIVE (900, 500, swfdec_sprite_movie_get_blendMode)
SWFDEC_AS_NATIVE (900, 501, swfdec_sprite_movie_set_blendMode)
SWFDEC_AS_NATIVE (900, 2, swfdec_sprite_movie_localToGlobal)
SWFDEC_AS_NATIVE (900, 3, swfdec_sprite_movie_globalToLocal)
SWFDEC_AS_NATIVE (900, 8, swfdec_sprite_movie_attachAudio)
SWFDEC_AS_NATIVE (900, 9, swfdec_sprite_movie_attachVideo)
SWFDEC_AS_NATIVE (900, 23, swfdec_sprite_movie_getInstanceAtDepth)
SWFDEC_AS_NATIVE (900, 24, swfdec_sprite_movie_getSWFVersion)
SWFDEC_AS_NATIVE (900, 25, swfdec_sprite_movie_attachBitmap)
SWFDEC_AS_NATIVE (900, 26, swfdec_sprite_movie_getRect)
SWFDEC_AS_NATIVE (900, 12, swfdec_sprite_movie_play)
SWFDEC_AS_NATIVE (900, 13, swfdec_sprite_movie_stop)
SWFDEC_AS_NATIVE (900, 7, swfdec_sprite_movie_getBytesLoaded)
SWFDEC_AS_NATIVE (900, 6, swfdec_sprite_movie_getBytesTotal)
SWFDEC_AS_NATIVE (900, 22, swfdec_sprite_movie_getNextHighestDepth)
SWFDEC_AS_NATIVE (900, 16, swfdec_sprite_movie_gotoAndPlay)
SWFDEC_AS_NATIVE (900, 17, swfdec_sprite_movie_gotoAndStop)
SWFDEC_AS_NATIVE (900, 14, swfdec_sprite_movie_nextFrame)
SWFDEC_AS_NATIVE (900, 15, swfdec_sprite_movie_prevFrame)
SWFDEC_AS_NATIVE (900, 4, swfdec_sprite_movie_hitTest)
SWFDEC_AS_NATIVE (900, 20, swfdec_sprite_movie_startDrag)
SWFDEC_AS_NATIVE (900, 21, swfdec_sprite_movie_stopDrag)
SWFDEC_AS_NATIVE (900, 1, swfdec_sprite_movie_swapDepths)
SWFDEC_AS_NATIVE (901, 0, swfdec_sprite_movie_createEmptyMovieClip)
SWFDEC_AS_NATIVE (900, 0, swfdec_sprite_movie_attachMovie)
SWFDEC_AS_NATIVE (900, 18, swfdec_sprite_movie_duplicateMovieClip)
SWFDEC_AS_NATIVE (900, 19, swfdec_sprite_movie_removeMovieClip)
SWFDEC_AS_NATIVE (900, 10, swfdec_sprite_movie_getDepth)
SWFDEC_AS_NATIVE (900, 5, swfdec_sprite_movie_getBounds)
SWFDEC_AS_NATIVE (900, 11, swfdec_sprite_movie_setMask)
SWFDEC_AS_NATIVE (666, 1, get_scaleMode)
SWFDEC_AS_NATIVE (666, 2, set_scaleMode)
SWFDEC_AS_NATIVE (666, 3, get_align)
SWFDEC_AS_NATIVE (666, 4, set_align)
SWFDEC_AS_NATIVE (666, 5, get_width)
SWFDEC_AS_NATIVE (666, 7, get_height)
SWFDEC_AS_NATIVE (666, 6, set_width)
SWFDEC_AS_NATIVE (666, 8, set_height)
SWFDEC_AS_NATIVE (666, 9, swfdec_stage_get_showMenu)
SWFDEC_AS_NATIVE (666, 10, swfdec_stage_set_showMenu)
SWFDEC_AS_NATIVE (666, 11, swfdec_stage_get_displayState)
SWFDEC_AS_NATIVE (666, 12, swfdec_stage_set_displayState)
SWFDEC_AS_NATIVE (666, 100, swfdec_stage_get_fullScreenSourceRect)
SWFDEC_AS_NATIVE (666, 101, swfdec_stage_set_fullScreenSourceRect)
SWFDEC_AS_NATIVE (666, 102, swfdec_stage_get_fullScreenHeight)
SWFDEC_AS_NATIVE (666, 103, swfdec_stage_set_fullScreenHeight)
SWFDEC_AS_NATIVE (666, 104, swfdec_stage_get_fullScreenWidth)
SWFDEC_AS_NATIVE (666, 105, swfdec_stage_set_fullScreenWidth)
SWFDEC_AS_NATIVE (113, 100, swfdec_style_sheet_update)
SWFDEC_AS_NATIVE (113, 101, swfdec_style_sheet_parseCSSInternal)
SWFDEC_AS_NATIVE (113, 102, swfdec_style_sheet_parseCSSFontFamily)
SWFDEC_AS_NATIVE (113, 103, swfdec_style_sheet_parseColor)
SWFDEC_AS_NATIVE (1066, 0, swfdec_system_setClipboard)
SWFDEC_AS_NATIVE (2107, 0, swfdec_system_showSettings)
SWFDEC_AS_NATIVE (2107, 1, swfdec_system_get_exactSettings)
SWFDEC_AS_NATIVE (2107, 2, swfdec_system_set_exactSettings)
SWFDEC_AS_NATIVE (2107, 3, swfdec_system_get_useCodepage)
SWFDEC_AS_NATIVE (2107, 4, swfdec_system_set_useCodepage)
SWFDEC_AS_NATIVE (11, 0, swfdec_system_query)
SWFDEC_AS_NATIVE (13, 0, swfdec_system_ime_getEnabled)
SWFDEC_AS_NATIVE (13, 1, swfdec_system_ime_setEnabled)
SWFDEC_AS_NATIVE (13, 2, swfdec_system_ime_getCovnersionMode)
SWFDEC_AS_NATIVE (13, 3, swfdec_system_ime_setConversionMode)
SWFDEC_AS_NATIVE (13, 4, swfdec_system_ime_setCompositionString)
SWFDEC_AS_NATIVE (13, 5, swfdec_system_ime_doConversion)
SWFDEC_AS_NATIVE (12, 0, swfdec_system_security_allowDomain)
SWFDEC_AS_NATIVE (12, 1, swfdec_system_security_allowInsecureDomain)
SWFDEC_AS_NATIVE (12, 2, swfdec_system_security_loadPolicyFile)
SWFDEC_AS_NATIVE (12, 3, swfdec_system_security_chooseLocalSwfPath)
SWFDEC_AS_NATIVE (12, 4, swfdec_system_security_escapeDomain)
SWFDEC_AS_NATIVE (12, 5, swfdec_system_security_get_sandboxType)
SWFDEC_AS_NATIVE (12, 6, swfdec_system_security_set_sandboxType)
SWFDEC_AS_NATIVE (15, 0, swfdec_system_security_policy_file_resolver_resolve)
SWFDEC_AS_NATIVE (104, 300, swfdec_text_field_movie_get_gridFitType)
SWFDEC_AS_NATIVE (104, 301, swfdec_text_field_movie_set_gridFitType)
SWFDEC_AS_NATIVE (104, 302, swfdec_text_field_movie_get_antiAliasType)
SWFDEC_AS_NATIVE (104, 303, swfdec_text_field_movie_set_antiAliasType)
SWFDEC_AS_NATIVE (104, 304, swfdec_text_field_movie_get_thickness)
SWFDEC_AS_NATIVE (104, 305, swfdec_text_field_movie_set_thickness)
SWFDEC_AS_NATIVE (104, 306, swfdec_text_field_movie_get_sharpness)
SWFDEC_AS_NATIVE (104, 307, swfdec_text_field_movie_set_sharpness)
SWFDEC_AS_NATIVE (104, 308, swfdec_text_field_movie_get_filters)
SWFDEC_AS_NATIVE (104, 309, swfdec_text_field_movie_set_filters)
SWFDEC_AS_NATIVE (104, 104, swfdec_text_field_movie_getNewTextFormat)
SWFDEC_AS_NATIVE (104, 105, swfdec_text_field_movie_setNewTextFormat)
SWFDEC_AS_NATIVE (104, 102, swfdec_text_field_movie_setTextFormat)
SWFDEC_AS_NATIVE (104, 101, swfdec_text_field_movie_getTextFormat)
SWFDEC_AS_NATIVE (104, 100, swfdec_text_field_movie_replaceSel)
SWFDEC_AS_NATIVE (104, 107, swfdec_text_field_movie_replaceText)
SWFDEC_AS_NATIVE (104, 201, swfdec_text_field_movie_getFontList)
SWFDEC_AS_NATIVE (104, 106, swfdec_text_field_movie_getDepth)
SWFDEC_AS_NATIVE (104, 103, swfdec_text_field_movie_removeTextField)
SWFDEC_AS_NATIVE (104, 200, swfdec_text_field_movie_createTextField)
SWFDEC_AS_NATIVE (104, 0, swfdec_text_field_movie_construct)
SWFDEC_AS_NATIVE (2150, 1, swfdec_text_renderer_setAdvancedAntialiasingTable)
SWFDEC_AS_NATIVE (2150, 2, swfdec_text_renderer_get_antiAliasType)
SWFDEC_AS_NATIVE (2150, 3, swfdec_text_renderer_set_antiAliasType)
SWFDEC_AS_NATIVE (2150, 4, swfdec_text_renderer_get_maxLevel)
SWFDEC_AS_NATIVE (2150, 5, swfdec_text_renderer_set_maxLevel)
SWFDEC_AS_NATIVE (2150, 10, swfdec_text_renderer_get_displayMode)
SWFDEC_AS_NATIVE (2150, 11, swfdec_text_renderer_set_displayMode)
SWFDEC_AS_NATIVE (2150, 0, swfdec_text_renderer_construct)
SWFDEC_AS_NATIVE (1067, 1, swfdec_text_snapshot_getCount)
SWFDEC_AS_NATIVE (1067, 2, swfdec_text_snapshot_setSelected)
SWFDEC_AS_NATIVE (1067, 3, swfdec_text_snapshot_getSelected)
SWFDEC_AS_NATIVE (1067, 4, swfdec_text_snapshot_getText)
SWFDEC_AS_NATIVE (1067, 5, swfdec_text_snapshot_getSelectedText)
SWFDEC_AS_NATIVE (1067, 6, swfdec_text_snapshot_hitTestTextNearPos)
SWFDEC_AS_NATIVE (1067, 7, swfdec_text_snapshot_findText)
SWFDEC_AS_NATIVE (1067, 8, swfdec_text_snapshot_setSelectColor)
SWFDEC_AS_NATIVE (1067, 9, swfdec_text_snapshot_getTextRunInfo)
SWFDEC_AS_NATIVE (1067, 0, swfdec_text_snapshot_construct)
SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_as_get_matrix)
SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_as_set_matrix)
SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_as_get_concatenatedMatrix)
SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_as_set_concatenatedMatrix)
SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_as_get_colorTransform)
SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_as_set_colorTransform)
SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_as_get_concatenatedColorTransform)
SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_as_set_concatenatedColorTransform)
SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_as_get_pixelBounds)
SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_as_set_pixelBounds)
SWFDEC_AS_NATIVE (667, 1, swfdec_video_attach_video)
SWFDEC_AS_NATIVE (667, 2, swfdec_video_clear)
SWFDEC_AS_NATIVE (253, 7, swfdec_xml_node_do_getNamespaceForPrefix)
SWFDEC_AS_NATIVE (253, 8, swfdec_xml_node_do_getPrefixForNamespace)
SWFDEC_AS_NATIVE (253, 1, swfdec_xml_node_cloneNode)
SWFDEC_AS_NATIVE (253, 2, swfdec_xml_node_do_removeNode)
SWFDEC_AS_NATIVE (253, 3, swfdec_xml_node_insertBefore)
SWFDEC_AS_NATIVE (253, 4, swfdec_xml_node_do_appendChild)
SWFDEC_AS_NATIVE (253, 5, swfdec_xml_node_hasChildNodes)
SWFDEC_AS_NATIVE (253, 6, swfdec_xml_node_do_toString)
SWFDEC_AS_NATIVE (100, 5, swfdec_xml_do_escape)
SWFDEC_AS_NATIVE (300, 0, swfdec_xml_do_oldParseXML)
SWFDEC_AS_NATIVE (253, 12, swfdec_xml_do_parseXML)
SWFDEC_AS_NATIVE (253, 10, swfdec_xml_createElement)
SWFDEC_AS_NATIVE (253, 11, swfdec_xml_createTextNode)
SWFDEC_AS_NATIVE (400, 0, swfdec_xml_socket_connect)
SWFDEC_AS_NATIVE (400, 1, swfdec_xml_socket_send)
SWFDEC_AS_NATIVE (400, 2, swfdec_xml_socket_close)
#undef SWFDEC_AS_CONSTRUCTOR
#undef SWFDEC_AS_NATIVE
#define SWFDEC_AS_NATIVE(x,y,func) SWFDEC_AS_CONSTRUCTOR(x,y,func,NULL)
#define SWFDEC_AS_CONSTRUCTOR(x,y,func,type) { x, y, func, G_STRINGIFY (func), type },
const struct { guint x, y; SwfdecAsNative func; const char *name; GType (* get_type) (void); } native_funcs[] = {
SWFDEC_AS_CONSTRUCTOR (252, 0, swfdec_as_array_construct, swfdec_as_array_get_type)
SWFDEC_AS_CONSTRUCTOR (107, 2, swfdec_as_boolean_construct, swfdec_as_boolean_get_type)
SWFDEC_AS_CONSTRUCTOR (103, 256, swfdec_as_date_construct, swfdec_as_date_get_type)
SWFDEC_AS_CONSTRUCTOR (106, 2, swfdec_as_number_construct, swfdec_as_number_get_type)
SWFDEC_AS_CONSTRUCTOR (251, 0, swfdec_as_string_construct, swfdec_as_string_get_type)
SWFDEC_AS_CONSTRUCTOR (1100, 0, swfdec_bitmap_data_construct, swfdec_bitmap_data_get_type)
SWFDEC_AS_CONSTRUCTOR (1105, 0, swfdec_color_transform_as_construct, swfdec_color_transform_as_get_type)
SWFDEC_AS_CONSTRUCTOR (112, 0, swfdec_movie_clip_loader_construct, swfdec_movie_clip_loader_get_type)
SWFDEC_AS_CONSTRUCTOR (2100, 200, swfdec_net_connection_construct, swfdec_net_connection_get_type)
SWFDEC_AS_CONSTRUCTOR (500, 16, swfdec_sound_object_construct, swfdec_sound_object_get_type)
SWFDEC_AS_CONSTRUCTOR (113, 0, swfdec_style_sheet_construct, swfdec_style_sheet_get_type)
SWFDEC_AS_CONSTRUCTOR (110, 0, swfdec_text_format_construct, swfdec_text_format_get_type)
SWFDEC_AS_CONSTRUCTOR (1106, 0, swfdec_transform_as_construct, swfdec_transform_as_get_type)
SWFDEC_AS_CONSTRUCTOR (253, 0, swfdec_xml_node_construct, swfdec_xml_node_get_type)
SWFDEC_AS_CONSTRUCTOR (253, 9, swfdec_xml_construct, swfdec_xml_get_type)
SWFDEC_AS_NATIVE (1999, 0, swfdec_accessibility_isActive)
SWFDEC_AS_NATIVE (1999, 1, swfdec_accessibility_sendEvent)
SWFDEC_AS_NATIVE (1999, 2, swfdec_accessibility_updateProperties)
SWFDEC_AS_NATIVE (252, 7, swfdec_as_array_join)
SWFDEC_AS_NATIVE (252, 9, swfdec_as_array_toString)
SWFDEC_AS_NATIVE (252, 1, swfdec_as_array_do_push)
SWFDEC_AS_NATIVE (252, 2, swfdec_as_array_do_pop)
SWFDEC_AS_NATIVE (252, 5, swfdec_as_array_do_unshift)
SWFDEC_AS_NATIVE (252, 4, swfdec_as_array_do_shift)
SWFDEC_AS_NATIVE (252, 11, swfdec_as_array_reverse)
SWFDEC_AS_NATIVE (252, 3, swfdec_as_array_concat)
SWFDEC_AS_NATIVE (252, 6, swfdec_as_array_slice)
SWFDEC_AS_NATIVE (252, 8, swfdec_as_array_splice)
SWFDEC_AS_NATIVE (252, 10, swfdec_as_array_sort)
SWFDEC_AS_NATIVE (252, 12, swfdec_as_array_sortOn)
SWFDEC_AS_NATIVE (107, 1, swfdec_as_boolean_toString)
SWFDEC_AS_NATIVE (107, 0, swfdec_as_boolean_valueOf)
SWFDEC_AS_NATIVE (3, 2, swfdec_as_boolean_old_constructor)
SWFDEC_AS_NATIVE (1, 0, swfdec_as_context_ASSetPropFlags)
SWFDEC_AS_NATIVE (200, 19, swfdec_as_context_isFinite)
SWFDEC_AS_NATIVE (200, 18, swfdec_as_context_isNaN)
SWFDEC_AS_NATIVE (100, 2, swfdec_as_context_parseInt)
SWFDEC_AS_NATIVE (100, 3, swfdec_as_context_parseFloat)
SWFDEC_AS_NATIVE (103, 19, swfdec_as_date_toString)
SWFDEC_AS_NATIVE (103, 16, swfdec_as_date_getTime)
SWFDEC_AS_NATIVE (103, 18, swfdec_as_date_getTimezoneOffset)
SWFDEC_AS_NATIVE (103, 8, swfdec_as_date_getMilliseconds)
SWFDEC_AS_NATIVE (103, 128 + 8, swfdec_as_date_getUTCMilliseconds)
SWFDEC_AS_NATIVE (103, 7, swfdec_as_date_getSeconds)
SWFDEC_AS_NATIVE (103, 128 + 7, swfdec_as_date_getUTCSeconds)
SWFDEC_AS_NATIVE (103, 6, swfdec_as_date_getMinutes)
SWFDEC_AS_NATIVE (103, 128 + 6, swfdec_as_date_getUTCMinutes)
SWFDEC_AS_NATIVE (103, 5, swfdec_as_date_getHours)
SWFDEC_AS_NATIVE (103, 128 + 5, swfdec_as_date_getUTCHours)
SWFDEC_AS_NATIVE (103, 4, swfdec_as_date_getDay)
SWFDEC_AS_NATIVE (103, 128 + 4, swfdec_as_date_getUTCDay)
SWFDEC_AS_NATIVE (103, 3, swfdec_as_date_getDate)
SWFDEC_AS_NATIVE (103, 128 + 3, swfdec_as_date_getUTCDate)
SWFDEC_AS_NATIVE (103, 2, swfdec_as_date_getMonth)
SWFDEC_AS_NATIVE (103, 128 + 2, swfdec_as_date_getUTCMonth)
SWFDEC_AS_NATIVE (103, 1, swfdec_as_date_getYear)
SWFDEC_AS_NATIVE (103, 128 + 1, swfdec_as_date_getUTCYear)
SWFDEC_AS_NATIVE (103, 0, swfdec_as_date_getFullYear)
SWFDEC_AS_NATIVE (103, 128 + 0, swfdec_as_date_getUTCFullYear)
SWFDEC_AS_NATIVE (103, 17, swfdec_as_date_setTime)
SWFDEC_AS_NATIVE (103, 15, swfdec_as_date_setMilliseconds)
SWFDEC_AS_NATIVE (103, 128 + 15, swfdec_as_date_setUTCMilliseconds)
SWFDEC_AS_NATIVE (103, 14, swfdec_as_date_setSeconds)
SWFDEC_AS_NATIVE (103, 128 + 14, swfdec_as_date_setUTCSeconds)
SWFDEC_AS_NATIVE (103, 13, swfdec_as_date_setMinutes)
SWFDEC_AS_NATIVE (103, 128 + 13, swfdec_as_date_setUTCMinutes)
SWFDEC_AS_NATIVE (103, 12, swfdec_as_date_setHours)
SWFDEC_AS_NATIVE (103, 128 + 12, swfdec_as_date_setUTCHours)
SWFDEC_AS_NATIVE (103, 11, swfdec_as_date_setDate)
SWFDEC_AS_NATIVE (103, 128 + 11, swfdec_as_date_setUTCDate)
SWFDEC_AS_NATIVE (103, 10, swfdec_as_date_setMonth)
SWFDEC_AS_NATIVE (103, 128 + 10, swfdec_as_date_setUTCMonth)
SWFDEC_AS_NATIVE (103, 20, swfdec_as_date_setYear)
SWFDEC_AS_NATIVE (103, 9, swfdec_as_date_setFullYear)
SWFDEC_AS_NATIVE (103, 128 + 9, swfdec_as_date_setUTCFullYear)
SWFDEC_AS_NATIVE (103, 257, swfdec_as_date_UTC)
SWFDEC_AS_NATIVE (101, 10, swfdec_as_function_do_call)
SWFDEC_AS_NATIVE (101, 11, swfdec_as_function_apply)
SWFDEC_AS_NATIVE (200, 16, swfdec_as_math_acos)
SWFDEC_AS_NATIVE (200, 15, swfdec_as_math_asin)
SWFDEC_AS_NATIVE (200, 14, swfdec_as_math_atan)
SWFDEC_AS_NATIVE (200, 13, swfdec_as_math_ceil)
SWFDEC_AS_NATIVE (200, 4, swfdec_as_math_cos)
SWFDEC_AS_NATIVE (200, 7, swfdec_as_math_exp)
SWFDEC_AS_NATIVE (200, 12, swfdec_as_math_floor)
SWFDEC_AS_NATIVE (200, 8, swfdec_as_math_log)
SWFDEC_AS_NATIVE (200, 3, swfdec_as_math_sin)
SWFDEC_AS_NATIVE (200, 9, swfdec_as_math_sqrt)
SWFDEC_AS_NATIVE (200, 6, swfdec_as_math_tan)
SWFDEC_AS_NATIVE (200, 0, swfdec_as_math_abs)
SWFDEC_AS_NATIVE (200, 5, swfdec_as_math_atan2)
SWFDEC_AS_NATIVE (200, 2, swfdec_as_math_max)
SWFDEC_AS_NATIVE (200, 1, swfdec_as_math_min)
SWFDEC_AS_NATIVE (200, 17, swfdec_as_math_pow)
SWFDEC_AS_NATIVE (200, 11, swfdec_as_math_random)
SWFDEC_AS_NATIVE (200, 10, swfdec_as_math_round)
SWFDEC_AS_NATIVE (106, 1, swfdec_as_number_toString)
SWFDEC_AS_NATIVE (106, 0, swfdec_as_number_valueOf)
SWFDEC_AS_NATIVE (3, 1, swfdec_as_number_old_constructor)
SWFDEC_AS_NATIVE (3, 4, swfdec_as_number_old_toString)
SWFDEC_AS_NATIVE (101, 2, swfdec_as_object_addProperty)
SWFDEC_AS_NATIVE (101, 5, swfdec_as_object_hasOwnProperty)
SWFDEC_AS_NATIVE (101, 7, swfdec_as_object_isPropertyEnumerable)
SWFDEC_AS_NATIVE (101, 6, swfdec_as_object_isPrototypeOf)
SWFDEC_AS_NATIVE (101, 0, swfdec_as_object_watch)
SWFDEC_AS_NATIVE (101, 1, swfdec_as_object_unwatch)
SWFDEC_AS_NATIVE (101, 3, swfdec_as_object_valueOf)
SWFDEC_AS_NATIVE (101, 4, swfdec_as_object_toString)
SWFDEC_AS_NATIVE (3, 3, swfdec_as_object_old_constructor)
SWFDEC_AS_NATIVE (251, 9, swfdec_as_string_lastIndexOf)
SWFDEC_AS_NATIVE (251, 8, swfdec_as_string_indexOf)
SWFDEC_AS_NATIVE (251, 5, swfdec_as_string_charAt)
SWFDEC_AS_NATIVE (251, 6, swfdec_as_string_charCodeAt)
SWFDEC_AS_NATIVE (251, 14, swfdec_as_string_fromCharCode)
SWFDEC_AS_NATIVE (251, 2, swfdec_as_string_toString)
SWFDEC_AS_NATIVE (251, 1, swfdec_as_string_valueOf)
SWFDEC_AS_NATIVE (251, 12, swfdec_as_string_split)
SWFDEC_AS_NATIVE (251, 10, swfdec_as_string_slice)
SWFDEC_AS_NATIVE (251, 7, swfdec_as_string_concat)
SWFDEC_AS_NATIVE (251, 13, swfdec_as_string_substr)
SWFDEC_AS_NATIVE (251, 11, swfdec_as_string_substring)
SWFDEC_AS_NATIVE (251, 4, swfdec_as_string_toLowerCase)
SWFDEC_AS_NATIVE (251, 3, swfdec_as_string_toUpperCase)
SWFDEC_AS_NATIVE (102, 1, swfdec_as_string_old_toLowerCase)
SWFDEC_AS_NATIVE (102, 0, swfdec_as_string_old_toUpperCase)
SWFDEC_AS_NATIVE (100, 0, swfdec_as_string_escape_internal)
SWFDEC_AS_NATIVE (100, 1, swfdec_as_string_unescape_internal)
SWFDEC_AS_NATIVE (3, 0, swfdec_as_string_old_constructor)
SWFDEC_AS_NATIVE (101, 12, broadcastMessage)
SWFDEC_AS_NATIVE (1107, 1, swfdec_bevel_filter_get_distance)
SWFDEC_AS_NATIVE (1107, 2, swfdec_bevel_filter_set_distance)
SWFDEC_AS_NATIVE (1107, 3, swfdec_bevel_filter_get_angle)
SWFDEC_AS_NATIVE (1107, 4, swfdec_bevel_filter_set_angle)
SWFDEC_AS_NATIVE (1107, 5, swfdec_bevel_filter_get_highlightColor)
SWFDEC_AS_NATIVE (1107, 6, swfdec_bevel_filter_set_highlightColor)
SWFDEC_AS_NATIVE (1107, 7, swfdec_bevel_filter_get_highlightAlpha)
SWFDEC_AS_NATIVE (1107, 8, swfdec_bevel_filter_set_highlightAlpha)
SWFDEC_AS_NATIVE (1107, 9, swfdec_bevel_filter_get_shadowColor)
SWFDEC_AS_NATIVE (1107, 10, swfdec_bevel_filter_set_shadowColor)
SWFDEC_AS_NATIVE (1107, 11, swfdec_bevel_filter_get_shadowAlpha)
SWFDEC_AS_NATIVE (1107, 12, swfdec_bevel_filter_set_shadowAlpha)
SWFDEC_AS_NATIVE (1107, 13, swfdec_bevel_filter_get_quality)
SWFDEC_AS_NATIVE (1107, 14, swfdec_bevel_filter_set_quality)
SWFDEC_AS_NATIVE (1107, 15, swfdec_bevel_filter_get_strength)
SWFDEC_AS_NATIVE (1107, 16, swfdec_bevel_filter_set_strength)
SWFDEC_AS_NATIVE (1107, 17, swfdec_bevel_filter_get_knockout)
SWFDEC_AS_NATIVE (1107, 18, swfdec_bevel_filter_set_knockout)
SWFDEC_AS_NATIVE (1107, 19, swfdec_bevel_filter_get_blurX)
SWFDEC_AS_NATIVE (1107, 20, swfdec_bevel_filter_set_blurX)
SWFDEC_AS_NATIVE (1107, 21, swfdec_bevel_filter_get_blurY)
SWFDEC_AS_NATIVE (1107, 22, swfdec_bevel_filter_set_blurY)
SWFDEC_AS_NATIVE (1107, 23, swfdec_bevel_filter_get_type)
SWFDEC_AS_NATIVE (1107, 24, swfdec_bevel_filter_set_type)
SWFDEC_AS_NATIVE (1107, 0, swfdec_bevel_filter_construct)
SWFDEC_AS_NATIVE (1100, 40, swfdec_bitmap_data_loadBitmap)
SWFDEC_AS_NATIVE (1100, 100, swfdec_bitmap_data_get_width)
SWFDEC_AS_NATIVE (1100, 101, swfdec_bitmap_data_set_width)
SWFDEC_AS_NATIVE (1100, 102, swfdec_bitmap_data_get_height)
SWFDEC_AS_NATIVE (1100, 103, swfdec_bitmap_data_set_height)
SWFDEC_AS_NATIVE (1100, 104, swfdec_bitmap_data_get_rectangle)
SWFDEC_AS_NATIVE (1100, 105, swfdec_bitmap_data_set_rectangle)
SWFDEC_AS_NATIVE (1100, 106, swfdec_bitmap_data_get_transparent)
SWFDEC_AS_NATIVE (1100, 107, swfdec_bitmap_data_set_transparent)
SWFDEC_AS_NATIVE (1100, 1, swfdec_bitmap_data_getPixel)
SWFDEC_AS_NATIVE (1100, 2, swfdec_bitmap_data_setPixel)
SWFDEC_AS_NATIVE (1100, 3, swfdec_bitmap_data_fillRect)
SWFDEC_AS_NATIVE (1100, 4, swfdec_bitmap_data_copyPixels)
SWFDEC_AS_NATIVE (1100, 5, swfdec_bitmap_data_applyFilter)
SWFDEC_AS_NATIVE (1100, 6, swfdec_bitmap_data_scroll)
SWFDEC_AS_NATIVE (1100, 7, swfdec_bitmap_data_threshold)
SWFDEC_AS_NATIVE (1100, 8, swfdec_bitmap_data_draw)
SWFDEC_AS_NATIVE (1100, 9, swfdec_bitmap_data_pixelDissolve)
SWFDEC_AS_NATIVE (1100, 10, swfdec_bitmap_data_getPixel32)
SWFDEC_AS_NATIVE (1100, 11, swfdec_bitmap_data_setPixel32)
SWFDEC_AS_NATIVE (1100, 12, swfdec_bitmap_data_floodFill)
SWFDEC_AS_NATIVE (1100, 13, swfdec_bitmap_data_getColorBoundsRect)
SWFDEC_AS_NATIVE (1100, 14, swfdec_bitmap_data_perlinNoise)
SWFDEC_AS_NATIVE (1100, 15, swfdec_bitmap_data_colorTransform)
SWFDEC_AS_NATIVE (1100, 16, swfdec_bitmap_data_hitTest)
SWFDEC_AS_NATIVE (1100, 17, swfdec_bitmap_data_paletteMap)
SWFDEC_AS_NATIVE (1100, 18, swfdec_bitmap_data_merge)
SWFDEC_AS_NATIVE (1100, 19, swfdec_bitmap_data_noise)
SWFDEC_AS_NATIVE (1100, 20, swfdec_bitmap_data_copyChannel)
SWFDEC_AS_NATIVE (1100, 21, swfdec_bitmap_data_clone)
SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_do_dispose)
SWFDEC_AS_NATIVE (1100, 23, swfdec_bitmap_data_generateFilterRect)
SWFDEC_AS_NATIVE (1100, 24, swfdec_bitmap_data_compare)
SWFDEC_AS_NATIVE (1112, 1, swfdec_bitmap_filter_getPixel)
SWFDEC_AS_NATIVE (1112, 0, swfdec_bitmap_filter_construct)
SWFDEC_AS_NATIVE (1102, 1, swfdec_blur_filter_get_blurX)
SWFDEC_AS_NATIVE (1102, 2, swfdec_blur_filter_set_blurX)
SWFDEC_AS_NATIVE (1102, 3, swfdec_blur_filter_get_blurY)
SWFDEC_AS_NATIVE (1102, 4, swfdec_blur_filter_set_blurY)
SWFDEC_AS_NATIVE (1102, 5, swfdec_blur_filter_get_quality)
SWFDEC_AS_NATIVE (1102, 6, swfdec_blur_filter_set_quality)
SWFDEC_AS_NATIVE (1102, 0, swfdec_blur_filter_construct)
SWFDEC_AS_NATIVE (105, 4, swfdec_button_get_scale9Grid)
SWFDEC_AS_NATIVE (105, 5, swfdec_button_set_scale9Grid)
SWFDEC_AS_NATIVE (105, 6, swfdec_button_get_filters)
SWFDEC_AS_NATIVE (105, 7, swfdec_button_set_filters)
SWFDEC_AS_NATIVE (105, 8, swfdec_button_get_cacheAsBitmap)
SWFDEC_AS_NATIVE (105, 9, swfdec_button_set_cacheAsBitmap)
SWFDEC_AS_NATIVE (105, 10, swfdec_button_get_blendMode)
SWFDEC_AS_NATIVE (105, 11, swfdec_button_set_blendMode)
SWFDEC_AS_NATIVE (105, 3, swfdec_button_movie_getDepth)
SWFDEC_AS_NATIVE (105, 0, swfdec_button_movie_construct)
SWFDEC_AS_NATIVE (2102, 200, swfdec_camera_get)
SWFDEC_AS_NATIVE (2102, 201, swfdec_camera_names_get)
SWFDEC_AS_NATIVE (2102, 0, swfdec_camera_setMode)
SWFDEC_AS_NATIVE (2102, 1, swfdec_camera_setQuality)
SWFDEC_AS_NATIVE (2102, 2, swfdec_camera_setKeyFrameInterval)
SWFDEC_AS_NATIVE (2102, 3, swfdec_camera_setMotionLevel)
SWFDEC_AS_NATIVE (2102, 4, swfdec_camera_setLoopback)
SWFDEC_AS_NATIVE (2102, 5, swfdec_camera_setCursor)
SWFDEC_AS_NATIVE (700, 2, swfdec_movie_color_getRGB)
SWFDEC_AS_NATIVE (700, 3, swfdec_movie_color_getTransform)
SWFDEC_AS_NATIVE (700, 0, swfdec_movie_color_setRGB)
SWFDEC_AS_NATIVE (700, 1, swfdec_movie_color_setTransform)
SWFDEC_AS_NATIVE (1110, 1, swfdec_color_matrix_filter_get_matrix)
SWFDEC_AS_NATIVE (1110, 2, swfdec_color_matrix_filter_set_matrix)
SWFDEC_AS_NATIVE (1110, 0, swfdec_color_matrix_filter_contruct)
SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_as_get_alphaMultiplier)
SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_as_set_alphaMultiplier)
SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_as_get_redMultiplier)
SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_as_set_redMultiplier)
SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_as_get_greenMultiplier)
SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_as_set_greenMultiplier)
SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_as_get_blueMultiplier)
SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_as_set_blueMultiplier)
SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_as_get_alphaOffset)
SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_as_set_alphaOffset)
SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_as_get_redOffset)
SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_as_set_redOffset)
SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_as_get_greenOffset)
SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_as_set_greenOffset)
SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_as_get_blueOffset)
SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_as_set_blueOffset)
SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_as_get_rgb)
SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_as_set_rgb)
SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_as_concat)
SWFDEC_AS_NATIVE (1109, 1, swfdec_convolution_filter_get_matrixX)
SWFDEC_AS_NATIVE (1109, 2, swfdec_convolution_filter_set_matrixX)
SWFDEC_AS_NATIVE (1109, 3, swfdec_convolution_filter_get_matrixY)
SWFDEC_AS_NATIVE (1109, 4, swfdec_convolution_filter_set_matrixY)
SWFDEC_AS_NATIVE (1109, 5, swfdec_convolution_filter_get_matrix)
SWFDEC_AS_NATIVE (1109, 6, swfdec_convolution_filter_set_matrix)
SWFDEC_AS_NATIVE (1109, 7, swfdec_convolution_filter_get_divisor)
SWFDEC_AS_NATIVE (1109, 8, swfdec_convolution_filter_set_divisor)
SWFDEC_AS_NATIVE (1109, 9, swfdec_convolution_filter_get_bias)
SWFDEC_AS_NATIVE (1109, 10, swfdec_convolution_filter_set_bias)
SWFDEC_AS_NATIVE (1109, 11, swfdec_convolution_filter_get_preserveAlpha)
SWFDEC_AS_NATIVE (1109, 12, swfdec_convolution_filter_set_preserveAlpha)
SWFDEC_AS_NATIVE (1109, 13, swfdec_convolution_filter_get_clamp)
SWFDEC_AS_NATIVE (1109, 14, swfdec_convolution_filter_set_clamp)
SWFDEC_AS_NATIVE (1109, 15, swfdec_convolution_filter_get_color)
SWFDEC_AS_NATIVE (1109, 16, swfdec_convolution_filter_set_color)
SWFDEC_AS_NATIVE (1109, 17, swfdec_convolution_filter_get_alpha)
SWFDEC_AS_NATIVE (1109, 18, swfdec_convolution_filter_set_alpha)
SWFDEC_AS_NATIVE (1109, 0, swfdec_convolution_filter_contruct)
SWFDEC_AS_NATIVE (1111, 1, swfdec_displacement_map_filter_get_mapBitmap)
SWFDEC_AS_NATIVE (1111, 2, swfdec_displacement_map_filter_set_mapBitmap)
SWFDEC_AS_NATIVE (1111, 3, swfdec_displacement_map_filter_get_mapPoint)
SWFDEC_AS_NATIVE (1111, 4, swfdec_displacement_map_filter_set_mapPoint)
SWFDEC_AS_NATIVE (1111, 5, swfdec_displacement_map_filter_get_componentX)
SWFDEC_AS_NATIVE (1111, 6, swfdec_displacement_map_filter_set_componentX)
SWFDEC_AS_NATIVE (1111, 7, swfdec_displacement_map_filter_get_componentY)
SWFDEC_AS_NATIVE (1111, 8, swfdec_displacement_map_filter_set_componentY)
SWFDEC_AS_NATIVE (1111, 9, swfdec_displacement_map_filter_get_scaleX)
SWFDEC_AS_NATIVE (1111, 10, swfdec_displacement_map_filter_set_scaleX)
SWFDEC_AS_NATIVE (1111, 11, swfdec_displacement_map_filter_get_scaleY)
SWFDEC_AS_NATIVE (1111, 12, swfdec_displacement_map_filter_set_scaleY)
SWFDEC_AS_NATIVE (1111, 13, swfdec_displacement_map_filter_get_mode)
SWFDEC_AS_NATIVE (1111, 14, swfdec_displacement_map_filter_set_mode)
SWFDEC_AS_NATIVE (1111, 15, swfdec_displacement_map_filter_get_color)
SWFDEC_AS_NATIVE (1111, 16, swfdec_displacement_map_filter_set_color)
SWFDEC_AS_NATIVE (1111, 17, swfdec_displacement_map_filter_get_alpha)
SWFDEC_AS_NATIVE (1111, 18, swfdec_displacement_map_filter_set_alpha)
SWFDEC_AS_NATIVE (1111, 0, swfdec_displacement_map_filter_contruct)
SWFDEC_AS_NATIVE (1101, 1, swfdec_drop_shadow_filter_get_distance)
SWFDEC_AS_NATIVE (1101, 2, swfdec_drop_shadow_filter_set_distance)
SWFDEC_AS_NATIVE (1101, 3, swfdec_drop_shadow_filter_get_angle)
SWFDEC_AS_NATIVE (1101, 4, swfdec_drop_shadow_filter_set_angle)
SWFDEC_AS_NATIVE (1101, 5, swfdec_drop_shadow_filter_get_color)
SWFDEC_AS_NATIVE (1101, 6, swfdec_drop_shadow_filter_set_color)
SWFDEC_AS_NATIVE (1101, 7, swfdec_drop_shadow_filter_get_alpha)
SWFDEC_AS_NATIVE (1101, 8, swfdec_drop_shadow_filter_set_alpha)
SWFDEC_AS_NATIVE (1101, 9, swfdec_drop_shadow_filter_get_quality)
SWFDEC_AS_NATIVE (1101, 10, swfdec_drop_shadow_filter_set_quality)
SWFDEC_AS_NATIVE (1101, 11, swfdec_drop_shadow_filter_get_inner)
SWFDEC_AS_NATIVE (1101, 12, swfdec_drop_shadow_filter_set_inner)
SWFDEC_AS_NATIVE (1101, 13, swfdec_drop_shadow_filter_get_knockout)
SWFDEC_AS_NATIVE (1101, 14, swfdec_drop_shadow_filter_set_knockout)
SWFDEC_AS_NATIVE (1101, 15, swfdec_drop_shadow_filter_get_blurX)
SWFDEC_AS_NATIVE (1101, 16, swfdec_drop_shadow_filter_set_blurX)
SWFDEC_AS_NATIVE (1101, 17, swfdec_drop_shadow_filter_get_blurY)
SWFDEC_AS_NATIVE (1101, 18, swfdec_drop_shadow_filter_set_blurY)
SWFDEC_AS_NATIVE (1101, 19, swfdec_drop_shadow_filter_get_strength)
SWFDEC_AS_NATIVE (1101, 20, swfdec_drop_shadow_filter_set_strength)
SWFDEC_AS_NATIVE (1101, 21, swfdec_drop_shadow_filter_get_hideObject)
SWFDEC_AS_NATIVE (1101, 22, swfdec_drop_shadow_filter_set_hideObject)
SWFDEC_AS_NATIVE (1101, 0, swfdec_drop_shadow_filter_construct)
SWFDEC_AS_NATIVE (14, 0, swfdec_external_interface__initJS)
SWFDEC_AS_NATIVE (14, 1, swfdec_external_interface__objectID)
SWFDEC_AS_NATIVE (14, 2, swfdec_external_interface__addCallback)
SWFDEC_AS_NATIVE (14, 3, swfdec_external_interface__evalJS)
SWFDEC_AS_NATIVE (14, 4, swfdec_external_interface__callOut)
SWFDEC_AS_NATIVE (14, 5, swfdec_external_interface__escapeXML)
SWFDEC_AS_NATIVE (14, 6, swfdec_external_interface__unescapeXML)
SWFDEC_AS_NATIVE (14, 7, swfdec_external_interface__jsQuoteString)
SWFDEC_AS_NATIVE (14, 100, swfdec_external_interface_get_available)
SWFDEC_AS_NATIVE (14, 101, swfdec_external_interface_set_available)
SWFDEC_AS_NATIVE (2204, 0, swfdec_file_reference_browse)
SWFDEC_AS_NATIVE (2204, 1, swfdec_file_reference_upload)
SWFDEC_AS_NATIVE (2204, 2, swfdec_file_reference_download)
SWFDEC_AS_NATIVE (2204, 3, swfdec_file_reference_cancel)
SWFDEC_AS_NATIVE (2204, 200, swfdec_file_reference_construct)
SWFDEC_AS_NATIVE (2205, 0, swfdec_file_reference_list_browse)
SWFDEC_AS_NATIVE (1112, 1, swfdec_filter_clone)
SWFDEC_AS_NATIVE (1103, 1, swfdec_glow_filter_get_distance)
SWFDEC_AS_NATIVE (1103, 2, swfdec_glow_filter_set_distance)
SWFDEC_AS_NATIVE (1103, 3, swfdec_glow_filter_get_alpha)
SWFDEC_AS_NATIVE (1103, 4, swfdec_glow_filter_set_alpha)
SWFDEC_AS_NATIVE (1103, 5, swfdec_glow_filter_get_quality)
SWFDEC_AS_NATIVE (1103, 6, swfdec_glow_filter_set_quality)
SWFDEC_AS_NATIVE (1103, 7, swfdec_glow_filter_get_inner)
SWFDEC_AS_NATIVE (1103, 8, swfdec_glow_filter_set_inner)
SWFDEC_AS_NATIVE (1103, 9, swfdec_glow_filter_get_knockout)
SWFDEC_AS_NATIVE (1103, 10, swfdec_glow_filter_set_knockout)
SWFDEC_AS_NATIVE (1103, 11, swfdec_glow_filter_get_blurX)
SWFDEC_AS_NATIVE (1103, 12, swfdec_glow_filter_set_blurX)
SWFDEC_AS_NATIVE (1103, 13, swfdec_glow_filter_get_blurY)
SWFDEC_AS_NATIVE (1103, 14, swfdec_glow_filter_set_blurY)
SWFDEC_AS_NATIVE (1103, 15, swfdec_glow_filter_get_strength)
SWFDEC_AS_NATIVE (1103, 16, swfdec_glow_filter_set_strength)
SWFDEC_AS_NATIVE (1103, 0, swfdec_glow_filter_construct)
SWFDEC_AS_NATIVE (1108, 1, swfdec_gradient_filter_get_distance)
SWFDEC_AS_NATIVE (1108, 2, swfdec_gradient_filter_set_distance)
SWFDEC_AS_NATIVE (1108, 3, swfdec_gradient_filter_get_angle)
SWFDEC_AS_NATIVE (1108, 4, swfdec_gradient_filter_set_angle)
SWFDEC_AS_NATIVE (1108, 5, swfdec_gradient_filter_get_colors)
SWFDEC_AS_NATIVE (1108, 6, swfdec_gradient_filter_set_colors)
SWFDEC_AS_NATIVE (1108, 7, swfdec_gradient_filter_get_alphas)
SWFDEC_AS_NATIVE (1108, 8, swfdec_gradient_filter_set_alphas)
SWFDEC_AS_NATIVE (1108, 9, swfdec_gradient_filter_get_ratios)
SWFDEC_AS_NATIVE (1108, 10, swfdec_gradient_filter_set_ratios)
SWFDEC_AS_NATIVE (1108, 11, swfdec_gradient_filter_get_blurX)
SWFDEC_AS_NATIVE (1108, 12, swfdec_gradient_filter_set_blurX)
SWFDEC_AS_NATIVE (1108, 13, swfdec_gradient_filter_get_blurY)
SWFDEC_AS_NATIVE (1108, 14, swfdec_gradient_filter_set_blurY)
SWFDEC_AS_NATIVE (1108, 15, swfdec_gradient_filter_get_quality)
SWFDEC_AS_NATIVE (1108, 16, swfdec_gradient_filter_set_quality)
SWFDEC_AS_NATIVE (1108, 17, swfdec_gradient_filter_get_strength)
SWFDEC_AS_NATIVE (1108, 18, swfdec_gradient_filter_set_strength)
SWFDEC_AS_NATIVE (1108, 19, swfdec_gradient_filter_get_knockout)
SWFDEC_AS_NATIVE (1108, 20, swfdec_gradient_filter_set_knockout)
SWFDEC_AS_NATIVE (1108, 21, swfdec_gradient_filter_get_type)
SWFDEC_AS_NATIVE (1108, 22, swfdec_gradient_filter_set_type)
SWFDEC_AS_NATIVE (1108, 0, swfdec_gradient_glow_filter_construct)
SWFDEC_AS_NATIVE (1108, 1000, swfdec_gradient_bevel_filter_construct)
SWFDEC_AS_NATIVE (800, 0, swfdec_key_getAscii)
SWFDEC_AS_NATIVE (800, 1, swfdec_key_getCode)
SWFDEC_AS_NATIVE (800, 2, swfdec_key_isDown)
SWFDEC_AS_NATIVE (800, 3, swfdec_key_isToggled)
SWFDEC_AS_NATIVE (800, 4, swfdec_key_isAccessible)
SWFDEC_AS_NATIVE (301, 0, swfdec_load_object_as_load)
SWFDEC_AS_NATIVE (301, 1, swfdec_load_object_as_send)
SWFDEC_AS_NATIVE (301, 2, swfdec_load_object_as_sendAndLoad)
SWFDEC_AS_NATIVE (301, 3, swfdec_loadvars_decode)
SWFDEC_AS_NATIVE (2200, 0, swfdec_local_connection_connect)
SWFDEC_AS_NATIVE (2200, 1, swfdec_local_connection_send)
SWFDEC_AS_NATIVE (2200, 2, swfdec_local_connection_close)
SWFDEC_AS_NATIVE (2200, 3, swfdec_local_connection_domain)
SWFDEC_AS_NATIVE (2104, 200, swfdec_microphone_get)
SWFDEC_AS_NATIVE (2104, 201, swfdec_microphone_names_get)
SWFDEC_AS_NATIVE (2104, 0, swfdec_microphone_setSilenceLevel)
SWFDEC_AS_NATIVE (2104, 1, swfdec_microphone_setRate)
SWFDEC_AS_NATIVE (2104, 2, swfdec_microphone_setGain)
SWFDEC_AS_NATIVE (2104, 3, swfdec_microphone_setUseEchoSuppression)
SWFDEC_AS_NATIVE (5, 0, swfdec_mouse_show)
SWFDEC_AS_NATIVE (5, 1, swfdec_mouse_hide)
SWFDEC_AS_NATIVE (901, 1, swfdec_sprite_movie_beginFill)
SWFDEC_AS_NATIVE (901, 2, swfdec_sprite_movie_beginGradientFill)
SWFDEC_AS_NATIVE (901, 3, swfdec_sprite_movie_moveTo)
SWFDEC_AS_NATIVE (901, 4, swfdec_sprite_movie_lineTo)
SWFDEC_AS_NATIVE (901, 5, swfdec_sprite_movie_curveTo)
SWFDEC_AS_NATIVE (901, 6, swfdec_sprite_movie_lineStyle)
SWFDEC_AS_NATIVE (901, 7, swfdec_sprite_movie_endFill)
SWFDEC_AS_NATIVE (901, 8, swfdec_sprite_movie_clear)
SWFDEC_AS_NATIVE (901, 9, swfdec_sprite_movie_lineGradientStyle)
SWFDEC_AS_NATIVE (901, 10, swfdec_sprite_movie_beginMeshFill)
SWFDEC_AS_NATIVE (901, 11, swfdec_sprite_movie_beginBitmapFill)
SWFDEC_AS_NATIVE (901, 12, swfdec_sprite_movie_get_scale9Grid)
SWFDEC_AS_NATIVE (901, 13, swfdec_sprite_movie_set_scale9Grid)
SWFDEC_AS_NATIVE (112, 100, swfdec_movie_clip_loader_loadClip)
SWFDEC_AS_NATIVE (112, 102, swfdec_movie_clip_loader_unloadClip)
SWFDEC_AS_NATIVE (112, 101, swfdec_movie_clip_loader_getProgress)
SWFDEC_AS_NATIVE (2100, 0, swfdec_net_connection_do_connect)
SWFDEC_AS_NATIVE (2100, 1, swfdec_net_connection_do_close)
SWFDEC_AS_NATIVE (2100, 2, swfdec_net_connection_do_call)
SWFDEC_AS_NATIVE (2100, 3, swfdec_net_connection_do_addHeader)
SWFDEC_AS_NATIVE (2100, 4, swfdec_net_connection_get_connectedProxyType)
SWFDEC_AS_NATIVE (2100, 5, swfdec_net_connection_get_usingTLS)
SWFDEC_AS_NATIVE (2101, 0, swfdec_net_stream_close)
SWFDEC_AS_NATIVE (2101, 1, swfdec_net_stream_attachAudio)
SWFDEC_AS_NATIVE (2101, 2, swfdec_net_stream_attachVideo)
SWFDEC_AS_NATIVE (2101, 3, swfdec_net_stream_send)
SWFDEC_AS_NATIVE (2101, 4, swfdec_net_stream_setBufferTime)
SWFDEC_AS_NATIVE (2101, 5, swfdec_net_stream_get_checkPolicyFile)
SWFDEC_AS_NATIVE (2101, 6, swfdec_net_stream_set_checkPolicyFile)
SWFDEC_AS_NATIVE (2, 0, swfdec_player_ASnew)
SWFDEC_AS_NATIVE (250, 0, swfdec_player_setInterval)
SWFDEC_AS_NATIVE (250, 2, swfdec_player_setTimeout)
SWFDEC_AS_NATIVE (250, 1, swfdec_player_clearInterval)
SWFDEC_AS_NATIVE (100, 4, swfdec_player_trace)
SWFDEC_AS_NATIVE (9, 0, swfdec_player_updateAfterEvent)
SWFDEC_AS_NATIVE (1021, 1, swfdec_player_showRedrawRegions)
SWFDEC_AS_NATIVE (4, 0, ASSetNative)
SWFDEC_AS_NATIVE (4, 1, ASSetNativeAccessor)
SWFDEC_AS_NATIVE (101, 8, swfdec_player_object_registerClass)
SWFDEC_AS_NATIVE (111, 100, swfdec_print_job_start)
SWFDEC_AS_NATIVE (111, 101, swfdec_print_job_addPage)
SWFDEC_AS_NATIVE (111, 102, swfdec_print_job_send)
SWFDEC_AS_NATIVE (111, 0, swfdec_print_job_construct)
SWFDEC_AS_NATIVE (600, 0, swfdec_selection_getBeginIndex)
SWFDEC_AS_NATIVE (600, 1, swfdec_selection_getEndIndex)
SWFDEC_AS_NATIVE (600, 2, swfdec_selection_getCaretIndex)
SWFDEC_AS_NATIVE (600, 3, swfdec_selection_getFocus)
SWFDEC_AS_NATIVE (600, 4, swfdec_selection_setFocus)
SWFDEC_AS_NATIVE (600, 5, swfdec_selection_setSelection)
SWFDEC_AS_NATIVE (2106, 0, swfdec_shared_object_connect)
SWFDEC_AS_NATIVE (2106, 1, swfdec_shared_object_send)
SWFDEC_AS_NATIVE (2106, 2, swfdec_shared_object_flush)
SWFDEC_AS_NATIVE (2106, 3, swfdec_shared_object_close)
SWFDEC_AS_NATIVE (2106, 4, swfdec_shared_object_getSize)
SWFDEC_AS_NATIVE (2106, 5, swfdec_shared_object_setFps)
SWFDEC_AS_NATIVE (2106, 6, swfdec_shared_object_clear)
SWFDEC_AS_NATIVE (500, 0, swfdec_sound_object_getPan)
SWFDEC_AS_NATIVE (500, 1, swfdec_sound_object_getTransform)
SWFDEC_AS_NATIVE (500, 2, swfdec_sound_object_getVolume)
SWFDEC_AS_NATIVE (500, 3, swfdec_sound_object_setPan)
SWFDEC_AS_NATIVE (500, 4, swfdec_sound_object_setTransform)
SWFDEC_AS_NATIVE (500, 5, swfdec_sound_object_setVolume)
SWFDEC_AS_NATIVE (500, 9, swfdec_sound_object_getDuration)
SWFDEC_AS_NATIVE (500, 10, swfdec_sound_object_setDuration)
SWFDEC_AS_NATIVE (500, 11, swfdec_sound_object_getPosition)
SWFDEC_AS_NATIVE (500, 12, swfdec_sound_object_setPosition)
SWFDEC_AS_NATIVE (500, 13, swfdec_sound_object_loadSound)
SWFDEC_AS_NATIVE (500, 14, swfdec_sound_object_getBytesLoaded)
SWFDEC_AS_NATIVE (500, 15, swfdec_sound_object_getBytesTotal)
SWFDEC_AS_NATIVE (500, 18, swfdec_sound_object_get_checkPolicyFile)
SWFDEC_AS_NATIVE (500, 19, swfdec_sound_object_set_checkPolicyFile)
SWFDEC_AS_NATIVE (500, 16, swfdec_sound_object_areSoundsInaccessible)
SWFDEC_AS_NATIVE (500, 7, swfdec_sound_object_attachSound)
SWFDEC_AS_NATIVE (500, 8, swfdec_sound_object_start)
SWFDEC_AS_NATIVE (500, 6, swfdec_sound_object_stop)
SWFDEC_AS_NATIVE (900, 200, swfdec_sprite_movie_get_tabIndex)
SWFDEC_AS_NATIVE (900, 201, swfdec_sprite_movie_set_tabIndex)
SWFDEC_AS_NATIVE (900, 300, swfdec_sprite_movie_get__lockroot)
SWFDEC_AS_NATIVE (900, 301, swfdec_sprite_movie_set__lockroot)
SWFDEC_AS_NATIVE (900, 401, swfdec_sprite_movie_get_cacheAsBitmap)
SWFDEC_AS_NATIVE (900, 402, swfdec_sprite_movie_set_cacheAsBitmap)
SWFDEC_AS_NATIVE (900, 403, swfdec_sprite_movie_get_opaqueBackground)
SWFDEC_AS_NATIVE (900, 404, swfdec_sprite_movie_set_opaqueBackground)
SWFDEC_AS_NATIVE (900, 405, swfdec_sprite_movie_get_scrollRect)
SWFDEC_AS_NATIVE (900, 406, swfdec_sprite_movie_set_scrollRect)
SWFDEC_AS_NATIVE (900, 417, swfdec_sprite_movie_get_filters)
SWFDEC_AS_NATIVE (900, 418, swfdec_sprite_movie_set_filters)
SWFDEC_AS_NATIVE (900, 419, swfdec_sprite_movie_get_transform)
SWFDEC_AS_NATIVE (900, 420, swfdec_sprite_movie_set_transform)
SWFDEC_AS_NATIVE (900, 500, swfdec_sprite_movie_get_blendMode)
SWFDEC_AS_NATIVE (900, 501, swfdec_sprite_movie_set_blendMode)
SWFDEC_AS_NATIVE (900, 2, swfdec_sprite_movie_localToGlobal)
SWFDEC_AS_NATIVE (900, 3, swfdec_sprite_movie_globalToLocal)
SWFDEC_AS_NATIVE (900, 8, swfdec_sprite_movie_attachAudio)
SWFDEC_AS_NATIVE (900, 9, swfdec_sprite_movie_attachVideo)
SWFDEC_AS_NATIVE (900, 23, swfdec_sprite_movie_getInstanceAtDepth)
SWFDEC_AS_NATIVE (900, 24, swfdec_sprite_movie_getSWFVersion)
SWFDEC_AS_NATIVE (900, 25, swfdec_sprite_movie_attachBitmap)
SWFDEC_AS_NATIVE (900, 26, swfdec_sprite_movie_getRect)
SWFDEC_AS_NATIVE (900, 12, swfdec_sprite_movie_play)
SWFDEC_AS_NATIVE (900, 13, swfdec_sprite_movie_stop)
SWFDEC_AS_NATIVE (900, 7, swfdec_sprite_movie_getBytesLoaded)
SWFDEC_AS_NATIVE (900, 6, swfdec_sprite_movie_getBytesTotal)
SWFDEC_AS_NATIVE (900, 22, swfdec_sprite_movie_getNextHighestDepth)
SWFDEC_AS_NATIVE (900, 16, swfdec_sprite_movie_gotoAndPlay)
SWFDEC_AS_NATIVE (900, 17, swfdec_sprite_movie_gotoAndStop)
SWFDEC_AS_NATIVE (900, 14, swfdec_sprite_movie_nextFrame)
SWFDEC_AS_NATIVE (900, 15, swfdec_sprite_movie_prevFrame)
SWFDEC_AS_NATIVE (900, 4, swfdec_sprite_movie_hitTest)
SWFDEC_AS_NATIVE (900, 20, swfdec_sprite_movie_startDrag)
SWFDEC_AS_NATIVE (900, 21, swfdec_sprite_movie_stopDrag)
SWFDEC_AS_NATIVE (900, 1, swfdec_sprite_movie_swapDepths)
SWFDEC_AS_NATIVE (901, 0, swfdec_sprite_movie_createEmptyMovieClip)
SWFDEC_AS_NATIVE (900, 0, swfdec_sprite_movie_attachMovie)
SWFDEC_AS_NATIVE (900, 18, swfdec_sprite_movie_duplicateMovieClip)
SWFDEC_AS_NATIVE (900, 19, swfdec_sprite_movie_removeMovieClip)
SWFDEC_AS_NATIVE (900, 10, swfdec_sprite_movie_getDepth)
SWFDEC_AS_NATIVE (900, 5, swfdec_sprite_movie_getBounds)
SWFDEC_AS_NATIVE (900, 11, swfdec_sprite_movie_setMask)
SWFDEC_AS_NATIVE (666, 1, get_scaleMode)
SWFDEC_AS_NATIVE (666, 2, set_scaleMode)
SWFDEC_AS_NATIVE (666, 3, get_align)
SWFDEC_AS_NATIVE (666, 4, set_align)
SWFDEC_AS_NATIVE (666, 5, get_width)
SWFDEC_AS_NATIVE (666, 7, get_height)
SWFDEC_AS_NATIVE (666, 6, set_width)
SWFDEC_AS_NATIVE (666, 8, set_height)
SWFDEC_AS_NATIVE (666, 9, swfdec_stage_get_showMenu)
SWFDEC_AS_NATIVE (666, 10, swfdec_stage_set_showMenu)
SWFDEC_AS_NATIVE (666, 11, swfdec_stage_get_displayState)
SWFDEC_AS_NATIVE (666, 12, swfdec_stage_set_displayState)
SWFDEC_AS_NATIVE (666, 100, swfdec_stage_get_fullScreenSourceRect)
SWFDEC_AS_NATIVE (666, 101, swfdec_stage_set_fullScreenSourceRect)
SWFDEC_AS_NATIVE (666, 102, swfdec_stage_get_fullScreenHeight)
SWFDEC_AS_NATIVE (666, 103, swfdec_stage_set_fullScreenHeight)
SWFDEC_AS_NATIVE (666, 104, swfdec_stage_get_fullScreenWidth)
SWFDEC_AS_NATIVE (666, 105, swfdec_stage_set_fullScreenWidth)
SWFDEC_AS_NATIVE (113, 100, swfdec_style_sheet_update)
SWFDEC_AS_NATIVE (113, 101, swfdec_style_sheet_parseCSSInternal)
SWFDEC_AS_NATIVE (113, 102, swfdec_style_sheet_parseCSSFontFamily)
SWFDEC_AS_NATIVE (113, 103, swfdec_style_sheet_parseColor)
SWFDEC_AS_NATIVE (1066, 0, swfdec_system_setClipboard)
SWFDEC_AS_NATIVE (2107, 0, swfdec_system_showSettings)
SWFDEC_AS_NATIVE (2107, 1, swfdec_system_get_exactSettings)
SWFDEC_AS_NATIVE (2107, 2, swfdec_system_set_exactSettings)
SWFDEC_AS_NATIVE (2107, 3, swfdec_system_get_useCodepage)
SWFDEC_AS_NATIVE (2107, 4, swfdec_system_set_useCodepage)
SWFDEC_AS_NATIVE (11, 0, swfdec_system_query)
SWFDEC_AS_NATIVE (13, 0, swfdec_system_ime_getEnabled)
SWFDEC_AS_NATIVE (13, 1, swfdec_system_ime_setEnabled)
SWFDEC_AS_NATIVE (13, 2, swfdec_system_ime_getCovnersionMode)
SWFDEC_AS_NATIVE (13, 3, swfdec_system_ime_setConversionMode)
SWFDEC_AS_NATIVE (13, 4, swfdec_system_ime_setCompositionString)
SWFDEC_AS_NATIVE (13, 5, swfdec_system_ime_doConversion)
SWFDEC_AS_NATIVE (12, 0, swfdec_system_security_allowDomain)
SWFDEC_AS_NATIVE (12, 1, swfdec_system_security_allowInsecureDomain)
SWFDEC_AS_NATIVE (12, 2, swfdec_system_security_loadPolicyFile)
SWFDEC_AS_NATIVE (12, 3, swfdec_system_security_chooseLocalSwfPath)
SWFDEC_AS_NATIVE (12, 4, swfdec_system_security_escapeDomain)
SWFDEC_AS_NATIVE (12, 5, swfdec_system_security_get_sandboxType)
SWFDEC_AS_NATIVE (12, 6, swfdec_system_security_set_sandboxType)
SWFDEC_AS_NATIVE (15, 0, swfdec_system_security_policy_file_resolver_resolve)
SWFDEC_AS_NATIVE (104, 300, swfdec_text_field_movie_get_gridFitType)
SWFDEC_AS_NATIVE (104, 301, swfdec_text_field_movie_set_gridFitType)
SWFDEC_AS_NATIVE (104, 302, swfdec_text_field_movie_get_antiAliasType)
SWFDEC_AS_NATIVE (104, 303, swfdec_text_field_movie_set_antiAliasType)
SWFDEC_AS_NATIVE (104, 304, swfdec_text_field_movie_get_thickness)
SWFDEC_AS_NATIVE (104, 305, swfdec_text_field_movie_set_thickness)
SWFDEC_AS_NATIVE (104, 306, swfdec_text_field_movie_get_sharpness)
SWFDEC_AS_NATIVE (104, 307, swfdec_text_field_movie_set_sharpness)
SWFDEC_AS_NATIVE (104, 308, swfdec_text_field_movie_get_filters)
SWFDEC_AS_NATIVE (104, 309, swfdec_text_field_movie_set_filters)
SWFDEC_AS_NATIVE (104, 104, swfdec_text_field_movie_getNewTextFormat)
SWFDEC_AS_NATIVE (104, 105, swfdec_text_field_movie_setNewTextFormat)
SWFDEC_AS_NATIVE (104, 102, swfdec_text_field_movie_setTextFormat)
SWFDEC_AS_NATIVE (104, 101, swfdec_text_field_movie_getTextFormat)
SWFDEC_AS_NATIVE (104, 100, swfdec_text_field_movie_replaceSel)
SWFDEC_AS_NATIVE (104, 107, swfdec_text_field_movie_replaceText)
SWFDEC_AS_NATIVE (104, 201, swfdec_text_field_movie_getFontList)
SWFDEC_AS_NATIVE (104, 106, swfdec_text_field_movie_getDepth)
SWFDEC_AS_NATIVE (104, 103, swfdec_text_field_movie_removeTextField)
SWFDEC_AS_NATIVE (104, 200, swfdec_text_field_movie_createTextField)
SWFDEC_AS_NATIVE (104, 0, swfdec_text_field_movie_construct)
SWFDEC_AS_NATIVE (2150, 1, swfdec_text_renderer_setAdvancedAntialiasingTable)
SWFDEC_AS_NATIVE (2150, 2, swfdec_text_renderer_get_antiAliasType)
SWFDEC_AS_NATIVE (2150, 3, swfdec_text_renderer_set_antiAliasType)
SWFDEC_AS_NATIVE (2150, 4, swfdec_text_renderer_get_maxLevel)
SWFDEC_AS_NATIVE (2150, 5, swfdec_text_renderer_set_maxLevel)
SWFDEC_AS_NATIVE (2150, 10, swfdec_text_renderer_get_displayMode)
SWFDEC_AS_NATIVE (2150, 11, swfdec_text_renderer_set_displayMode)
SWFDEC_AS_NATIVE (2150, 0, swfdec_text_renderer_construct)
SWFDEC_AS_NATIVE (1067, 1, swfdec_text_snapshot_getCount)
SWFDEC_AS_NATIVE (1067, 2, swfdec_text_snapshot_setSelected)
SWFDEC_AS_NATIVE (1067, 3, swfdec_text_snapshot_getSelected)
SWFDEC_AS_NATIVE (1067, 4, swfdec_text_snapshot_getText)
SWFDEC_AS_NATIVE (1067, 5, swfdec_text_snapshot_getSelectedText)
SWFDEC_AS_NATIVE (1067, 6, swfdec_text_snapshot_hitTestTextNearPos)
SWFDEC_AS_NATIVE (1067, 7, swfdec_text_snapshot_findText)
SWFDEC_AS_NATIVE (1067, 8, swfdec_text_snapshot_setSelectColor)
SWFDEC_AS_NATIVE (1067, 9, swfdec_text_snapshot_getTextRunInfo)
SWFDEC_AS_NATIVE (1067, 0, swfdec_text_snapshot_construct)
SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_as_get_matrix)
SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_as_set_matrix)
SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_as_get_concatenatedMatrix)
SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_as_set_concatenatedMatrix)
SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_as_get_colorTransform)
SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_as_set_colorTransform)
SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_as_get_concatenatedColorTransform)
SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_as_set_concatenatedColorTransform)
SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_as_get_pixelBounds)
SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_as_set_pixelBounds)
SWFDEC_AS_NATIVE (667, 1, swfdec_video_attach_video)
SWFDEC_AS_NATIVE (667, 2, swfdec_video_clear)
SWFDEC_AS_NATIVE (253, 7, swfdec_xml_node_do_getNamespaceForPrefix)
SWFDEC_AS_NATIVE (253, 8, swfdec_xml_node_do_getPrefixForNamespace)
SWFDEC_AS_NATIVE (253, 1, swfdec_xml_node_cloneNode)
SWFDEC_AS_NATIVE (253, 2, swfdec_xml_node_do_removeNode)
SWFDEC_AS_NATIVE (253, 3, swfdec_xml_node_insertBefore)
SWFDEC_AS_NATIVE (253, 4, swfdec_xml_node_do_appendChild)
SWFDEC_AS_NATIVE (253, 5, swfdec_xml_node_hasChildNodes)
SWFDEC_AS_NATIVE (253, 6, swfdec_xml_node_do_toString)
SWFDEC_AS_NATIVE (100, 5, swfdec_xml_do_escape)
SWFDEC_AS_NATIVE (300, 0, swfdec_xml_do_oldParseXML)
SWFDEC_AS_NATIVE (253, 12, swfdec_xml_do_parseXML)
SWFDEC_AS_NATIVE (253, 10, swfdec_xml_createElement)
SWFDEC_AS_NATIVE (253, 11, swfdec_xml_createTextNode)
SWFDEC_AS_NATIVE (400, 0, swfdec_xml_socket_connect)
SWFDEC_AS_NATIVE (400, 1, swfdec_xml_socket_send)
SWFDEC_AS_NATIVE (400, 2, swfdec_xml_socket_close)
  { 0, 0, NULL }
};
#undef SWFDEC_AS_CONSTRUCTOR
#undef SWFDEC_AS_NATIVE
